% addfloatcon.m
%   incorporate mean float velocities and their errors for 
%   segments of a hydrographic section.  This code translates
%   the velocities to mass transports using the layer areas
%   in the segment.  "addcon.m" is then called for each
%   segment.

clf;plot(lon,lat,'.k','markersize',1);
hold on;

% load variables from float file: errors, latitude,
%	longitude, velocities, floatlayers
eval(['load ',floatfilename,';']);

% load layer thicknesses
eval(['load ',sectfiles(SectNum,:),' thick;']);
% retain thicknesses of relevant layers
thick=sum(thick(floatlayers,:),1);

% loop through segments

for flind=1:length(velocities);

  col=rand(1,3);

  % define a polygon using the longitude,
  % latitude values from the float file
  Px=[longitude(flind) longitude(flind+1) ...
                longitude(flind+1) longitude(flind)];
  Py=[latitude(flind) latitude(flind+1) ...
                latitude(flind+1) latitude(flind)];
  Del=sqrt((longitude(flind+1)-longitude(flind)).^2 ...
	+(latitude(flind+1)-latitude(flind)).^2);
  Pthet=-atan2(latitude(flind+1)-latitude(flind), ...
	longitude(flind+1)-longitude(flind));
  Px=Px+.25*Del*sin(Pthet)*[1 1 -1 -1];
  Py=Py+.25*Del*cos(Pthet)*[1 1 -1 -1];

  plot([Px,Px(1)],[Py,Py(1)],'color',col);

  % identify the station numbers for this segment
  q=find(sectlabel==SectNum);
  statnum=find(isinpoly(lon(q),lat(q),Px,Py));
  plot(lon(q(statnum)),lat(q(statnum)),'o', ...
	'color',col);
  quiver([median(lon(q(statnum))) 0], ...
	[median(lat(q(statnum))) 0], ...
	100*[velocities(flind)*sin(Pthet) 0], ...
	100*[velocities(flind)*cos(Pthet) 0],0);

  sectnum=SectNum;
  propnum=1;
  boxnum=BoxNum;
  layernum=floatlayers;
  % layer area = thick(statnum)  [1-by-npairs]
  %   *R(q(statnum))  [npairs-by-1]
  fluxvalue=thick(statnum)*R(q(statnum)) ...
	*velocities(flind);
  fluxerror=thick(statnum)*R(q(statnum)) ...
	*errors(flind);
  textst=[num2str(fluxvalue/1e6,2), ...
	'\pm',num2str(fluxerror/1e6,2)];
  text(median(lon(q(statnum)))+2*sin(Pthet), ...
	median(lat(q(statnum)))+2*cos(Pthet), ...
	textst,'horizontalalignment','center');

  addcon;

end;	% loop through segments

hold off;
set(gca,'dataaspectratio',[1 1 1])
title('Float constraints (Sv)','fontsize',15);
%keyboard;

clear propnum sectnum boxnum layernum fluxvalue
clear fluxerror i stns pfluxrel EkIn statnum;
clear Px Py Pthet Del col flind;
clear BoxNum SectNum floatfilename thick;
clear errors floatlayers latitude longitude velocities;

