function barflux(massn,Sv2deg,avgnum);

% barflux(massn,Sv2deg,avgnum)
%
% Plot bars showing the transport across the
% sections, averaged over layers indicated by
% massn (defined in waterdiv.m) or in an individual
% model layer (massn=-12 for layer 12).
% 1 Sv spans Sv2deg degrees on the plot (default=.5)
% avgnum is the number of stations for each bar 
% (default=3; small numbers produce large error bars
% while large numbers average over important features)

load gaussout lon lat sectlabel nsections x erx Ax D ...
	A Pxx glayers indb indv EkmanE fluxdivfact fluxunits
massnum=massn;

% North Atlantic:
%minlon=-75; maxlon=0; minlat=35; maxlat=75;
% overall Atlantic N. of 20S:
minlon=-100; maxlon=20; minlat=-20; maxlat=max(lat)+3;
% focus on 24N sections
%minlon=-100; maxlon=0; minlat=10; maxlat=40;


ploterror=0;    % set to 1 for error bars

propnum=1;
waterdiv;
if (massnum>0)
  titl=waterdivslab(massnum,:);
elseif (massnum<0 & length(massnum)==1)
  titl=['layer ',num2str(-massnum)];
else
  titl=['layers ',num2str(-(max(massnum))), ...
	'-',num2str(-(min(massnum)))];
end;
if (massnum==0)
  nlyr=1:length(glayers);
  titl='vertically-integrated';
elseif (massnum==1)
  nlyr=find(glayers<waterdivs(massnum));
elseif (massnum==length(waterdivs)+1)
  nlyr=find(glayers>=last(waterdivs));
elseif (massnum>1 & massnum<length(waterdivs)+1)
  nlyr=find(glayers>=waterdivs(massnum-1) & ...
        glayers<waterdivs(massnum));
else
  nlyr=-massnum;
end;

if ~exist('Sv2deg');
  Sv2deg=.5;	% 1 Sv spans this many degrees on plot
end;
if ~exist('avgnum');
  avgnum=3;
end;
if (avgnum/2==floor(avgnum/2)) 	% avgnum must be an odd number
  avgnum=avgnum+1
end;

hold off;
if (1)	% just coastlines
    overlay;
elseif (0)  % superimpose plot on bathymetry
  load bathyatl;
  q=find(z2>0);z2(q)=1000;
  l=-5000:1000:1000;
  q=find(z2<min(l));z2(q)=min(l);
  [C,H]=contourf(lon2,lat2,z2,l);
  colormap bone
  colormap(flipud(colormap));
  set(H,'edgecolor','none');
  set(gca,'layer','top')
  colorbarvertbig;
else	% superimpose plot on salinity
  Lon=lon;Lat=lat;
  load /phod007/lumpkin/sac/modellayers Sg lon lat;
  ss=Sg(:,:,nlyr);ss2=NaN*ones(length(lat),length(lon));
  for i=1:length(lat);for j=1:length(lon);
    ss2(i,j)=nanmean(ss(i,j,:));
  end; end;
  q=find(lat<minlat);lat(q)=[];ss2(q,:)=[];
  contourfill(lon,lat,ss2,6);
  overlay;
  %colormap bone;
  %colormap(flipud(colormap));
  %F=colormap; colormap(.8*F+.1);
  clear ss ss2;
  lon=Lon;lat=Lat;
end;
set(gca,'dataaspectratio',[1 1 1]);
wysiwyg;
mapaxis([minlon maxlon minlat maxlat]);
hold on;

for sectnum=1:nsections;

geo;
boxnum=min(find(abs(geometry(:,sectnum))));

if (0)
if (sectnum==1) boxnum=1;
elseif (sectnum==2 | sectnum==3 | sectnum==4);
  boxnum=2;
elseif (sectnum==5) boxnum=3;
elseif (sectnum==6) boxnum=3;
elseif (sectnum==7); boxnum=4;
elseif (sectnum==8); boxnum=4;
elseif (sectnum==9); boxnum=4;
end;
end;

q=find(sectlabel==sectnum);
if (min(lon(q))<maxlon & max(lon(q))>minlon & ...
	min(lat(q))<maxlat & max(lat(q))>minlat)

plot(lon(q),lat(q),'color',[.5 .5 .5]);
%if (last(lon(q))>lon(q(1)))
  %q=flipud(q);
%end;

[dist,ang]=sw_dist(lat(q),lon(q),'km');
ang=ang*2*pi/360;
ang=[ang(1);ang(1:length(ang)-1)+diff(ang)/2;last(ang)];
if (geometry(boxnum,sectnum)<0)
  ang=ang+pi;
end;

pfluxref=NaN*ones(size(q));
pfluxrel=pfluxref;eref=pfluxref;
angle=pfluxref;latflux=pfluxref;lonflux=pfluxref;
for i=1+(avgnum-1)/2:avgnum:length(q)-(avgnum-1)/2;
  indx=i-(avgnum-1)/2 : i+(avgnum-1)/2;
  fluxref=sum(Ax(indb(nlyr,propnum,boxnum), ...
	indv(q(indx))));
  fluxrel=-sum(D(indb(nlyr,propnum,boxnum), ...
	indv(q(indx))));

  h=A(indb(nlyr,propnum,boxnum),indv(q(indx)))';
  eref(i)=sqrt(  sum(sum(h'*Pxx(indv(q(indx)),indv(q(indx)))*h))  );

  angle(i)=ang(i);
  lonflux(i)=lon(q(i));
  latflux(i)=lat(q(i));

  pfluxref(i)=sum(fluxref);
  pfluxrel(i)=sum(fluxrel);
end;
i=1+(avgnum-1)/2:avgnum:length(q)-(avgnum-1)/2;
if (max(i)<length(q)-(avgnum-1)/2)
  indx=max(i)+(avgnum-1)/2+1:length(q);
  pfluxref(length(q))=sum(sum(Ax(indb(nlyr,propnum,boxnum), ...
        indv(q(indx)))));
  pfluxrel(length(q))=-sum(sum(D(indb(nlyr,propnum,boxnum), ...
        indv(q(indx)))));
  h=A(indb(nlyr,propnum,boxnum),indv(q(indx)))';
  eref(length(q))=sqrt(  sum(sum(h'*Pxx(indv(q(indx)),indv(q(indx)))*h))  );
  angle(length(q))=mean(ang(indx));
end;

% EkIn: the total Ekman flux across that section
% (individual station pair information has not been saved).
EkIn=sum(sum(EkmanE(nlyr,propnum,boxnum,sectnum),1));
if (EkIn)
  % distribute EkIn evenly among the station pairs
  % (cum. sum climbs steadily to total EkIn)
  EkIn=ones(size(pfluxref))*EkIn/length(find(isfinite(pfluxref)));
else
  EkIn=zeros(size(pfluxref));
end;
jj=find(isnan(pfluxref));EkIn(jj)=NaN;

pfluxref=Sv2deg*pfluxref/fluxdivfact(propnum);
eref=abs(Sv2deg*eref/fluxdivfact(propnum));
pfluxrel=Sv2deg*pfluxrel/fluxdivfact(propnum);
EkIn=Sv2deg*EkIn/fluxdivfact(propnum);

netflux=pfluxref+pfluxrel+EkIn;

%if (sectnum==7)
  %disp('changing angle of Eriador inflow')
  %indd=find(abs(netflux)>4 & lon(q)>-30);
  %angle(indd)=-50*2*pi/360;
%end;

u=-netflux.*sin(angle);
eu=-eref.*sin(angle);
v=netflux.*cos(angle);
ev=eref.*cos(angle);

q2=find(isfinite(netflux));
for i=1:length(q2)
  plot([lonflux(q2(i)) lonflux(q2(i))+u(q2(i))], ...
	[latflux(q2(i)) latflux(q2(i))+v(q2(i))], ...
	'k','linewidth',4);
  if (ploterror)
    plot(lonflux(q2(i))+u(q2(i)), ...
	latflux(q2(i))+v(q2(i)),'.w','markersize',8);
    plot([lonflux(q2(i))+u(q2(i))+eu(q2(i)) ...
	lonflux(q2(i))+u(q2(i))-eu(q2(i))], ...
	[latflux(q2(i))+v(q2(i))+ev(q2(i)), ...
	latflux(q2(i))+v(q2(i))-ev(q2(i))], ...
	'w','linewidth',1);
  end;
end;

end;	% if-loop for section within minlon,maxlon,
	%	minlat, maxlat
end;	% loop over sections

title(titl,'fontsize',15);

 
% make legend

legend=[minlon+.1*(maxlon-minlon), ...
	maxlat-.2*(maxlat-minlat)];
legendflux=round(5/Sv2deg);
dx=2*legendflux*Sv2deg;
dy=dx/3;
patch([legend(1)-dx/2 legend(1)-dx/2 ...
        legend(1)+dx/2 legend(1)+dx/2], ...
        [legend(2)-dy/2 legend(2)+dy/2 ...
        legend(2)+dy/2 legend(2)-dy/2],'w');
hold on;
P=quiver([legend(1)-Sv2deg*legendflux/2 0], ...
        [legend(2)+dy/5 0],Sv2deg*[legendflux 0],[0 0],0,'.');
set(P,'color','k','linewidth',4);
text(legend(1),legend(2)-dy/4, ...
        [num2str(legendflux),fluxunits(propnum,:)], ...
        'horizontalalignment','center','fontsize',8);

hold off;


