  % calcweighedflux - calculate mean temperature and salinity
  % weighted by the transports into and out of the box.
  %   Program for Tania's PhD work in the Agulhas region
  %   (R. Lumpkin, July 2007)
 
  clear all;
  load gaussout Ax D EkmanE ind* sectfiles sectlabel
 
  propnum=1;
  boxnum=1;
  sectnum=1;
  laynum=1:45;
  laynum=5:6;
 
  % calculate mass (actually volume, in m^3/s) flux: %   positive into box, negative out of box
  q=find(sectlabel==sectnum);
  mass_pfluxref=Ax(indb(laynum,propnum,boxnum),indv(q));
  mass_pfluxrel=-D(indb(laynum,propnum,boxnum),indv(q));
  mass_pfluxek=EkmanE(laynum,propnum,boxnum,sectnum);
 
  % calculate transport-weighted potential temperature and salinity
  eval(['load ',sectfiles(sectnum,:),' LayerPair_potmp LayerPair_salam']);
  LayerPair_potmp=LayerPair_potmp(laynum,:);
  LayerPair_salam=LayerPair_salam(laynum,:);
  % placeholder for "doesn't exist" is 0.  Switch to NaN.
  q=find(LayerPair_potmp==0);
  LayerPair_potmp(q)=NaN;
  q=find(LayerPair_salam==0);
  LayerPair_salam(q)=NaN;
 
  % for Ekman, assume that the transport is in the shallowest layer.
  Ekman=zeros(size(mass_pfluxrel));
  for i=1:size(Ekman,1);  % looping through layers
      q=find((LayerPair_potmp(i,:)));
      if (length(q))
          Ekman(i,q)=mass_pfluxek(i)/length(q);
      end;
  end;
  mass_pfluxek=Ekman; clear Ekman;
 
  % calculate overall mass flux in each layer, for each station pair
  mass_flux=mass_pfluxrel+mass_pfluxref+mass_pfluxek;
  fprintf(['Mean transport: ', ...
          num2str(sum(sum(mass_flux))/1e6,'%3.3f'),' Sv.\n']);
 
  % transport weighted values INTO box
  q=find(mass_flux>0 & isfinite(LayerPair_potmp));
  TbarP=sum(sum(mass_flux(q).*LayerPair_potmp(q)))./ ...
      sum(sum(mass_flux(q)));
  fprintf('Mean pot.temperature weighted by transport into box: ');
  fprintf(num2str(TbarP,'%3.2f'));
  fprintf(' degC.\n')
  q=find(mass_flux>0 & isfinite(LayerPair_salam));
  SbarP=35+1e3*sum(sum(mass_flux(q).*LayerPair_salam(q)))./ ...
      sum(sum(mass_flux(q)));
  fprintf('Mean salinity weighted by transport into box: ');
  fprintf(num2str(SbarP,'%3.2f'));
  fprintf(' psu.\n')
  % transport weighted values OUT OF box
  q=find(mass_flux<0 & isfinite(LayerPair_potmp));
  TbarM=sum(sum(mass_flux(q).*LayerPair_potmp(q)))./ ...
      sum(sum(mass_flux(q)));
  fprintf('Mean pot.temperature weighted by transport out of box: ');
  fprintf(num2str(TbarM,'%3.2f'));
  fprintf(' degC.\n')
  q=find(mass_flux<0 & isfinite(LayerPair_salam));
  SbarM=35+1e3*sum(sum(mass_flux(q).*LayerPair_salam(q)))./ ...
      sum(sum(mass_flux(q)));
  fprintf('Mean salinity weighted by transport out of box: ');
  fprintf(num2str(SbarM,'%3.2f'));
  fprintf(' psu.\n')
