% changeairsea.m
%
% Set the air/sea fluxes of heat and freshwater,
% and the resulting formation/transformation,
% equal to one of the climatologies.  
% allow the model to adjust these within 1%
% (basically fixed ... allow 10% for Ekman)
% 
% In boxes against Antarctica, and for the
% Arctic/GIN Seas box, increase
% the errors to 100% to allow for much larger
% adjustments.  Find the layer which has the
% maximum error, and assign this error to all
% denser layers as well.  This adjustment will 
% accomodate processes such as heat loss in
% polynyas, e.g. layers with zero fluxes in the
% coarsly-gridded climatologies.

clear all;
geo;
nboxes=size(geometry,1);
load gaussout Fcorr_multfact

climatnumber=0;  % climatology number. 
                % set to 0 for ensemble mean.
                % 1=UWM/COADS, 2=SOC unadj. 3=SOC adj. 
		        % 4=NCEP, 5=ERA-15, 
                % -1=zero air-sea flux a priori (hard-coded for
                %   particular boxes; see below)

glev;
disp('Loading geometry file "geo".');
file_geom='geo'; eval(file_geom);
if (climatnumber==0)
    climname='ensemble mean';
elseif(climatnumber==1)
    climname='UWM/COADS';
elseif (climatnumber==2)
    climname='SOC/COADS (unadjusted)';
elseif (climatnumber==3)
    climname='SOC/COADS (adjusted)';
elseif (climatnumber==4)
    climname='NCEP/NCAR Reanalysis V2';
elseif (climatnumber==5)
    climname='ECMWF Reanalysis 15yr';
elseif (climatnumber==-1)
    climname='zero a priori';
else
    climname='unknown';
end;
fprintf('Switching air-sea fluxes to %s.\n',climname);

for boxnum=1:nboxes;
    loadairseaclims; % calculate t* vectors
    
    if (climatnumber>0)  % fixed to one air-sea product
        
    errF=0.01;  % only 1% adjustment - basically fixed.
    errF_ek=.1;    
        
    Ffw=[tFfw(climatnumber,:);errF*abs(tFfw(climatnumber,:))];
    Fh=[tFh(climatnumber,:);errF*abs(tFh(climatnumber,:))];
    Fm=[tFm(climatnumber,:);errF*abs(tFm(climatnumber,:))];
    Mm=[tMm(climatnumber,:);errF*abs(tMm(climatnumber,:))];
    EkmanInM_range=errF_ek*abs(sum(tEkmanInM(:,:,climatnumber))');
    
    Mhek=[tMhek(climatnumber,:)];
    Mmek=[tMmek(climatnumber,:)];
    Msek=[tMsek(climatnumber,:)];
    EkmanInM=[tEkmanInM(:,:,climatnumber)];
    EkmanInH=[tEkmanInH(:,:,climatnumber)];
    EkmanInS=[tEkmanInS(:,:,climatnumber)];
    EkmanInSalt=[tEkmanInSalt(:,:,climatnumber)];
    SSArea=[tSSArea(climatnumber,:)];
    SSSbar=[tSSSbar(climatnumber,:)];
    SSTbar=[tSSTbar(climatnumber,:)];
    
    else % climatnumber<=0
        
    errF=1; 
    errF_ek=1;    
    
    EkmanInH=mean(tEkmanInH,3);
    EkmanInM=mean(tEkmanInM,3);
    EkmanInS=mean(tEkmanInS,3);
    EkmanInSalt=mean(tEkmanInSalt,3);
    EkmanInM_range=errF_ek*sum(tEkmanInM,1);
    EkmanInM_range=reshape(EkmanInM_range, ...
	    [size(tEkmanInM,2) nclims]);
    EkmanInM_range=range(EkmanInM_range')';
    Ffw=[mean(tFfw);errF*range(tFfw)/2];
    %Ffw_norivers=[mean(tFfw_norivers); ...
	   %errF*range(tFfw_norivers)/2];
    Fh=[mean(tFh);errF*range(tFh)/2];
    Fm=[mean(tFm);errF*range(tFm)/2];
    Mhek=mean(tMhek);
    Mm=[mean(tMm);errF*range(tMm)/2];
    Mmek=mean(tMmek);
    Msek=mean(tMsek);
    SSArea=nanmean(tSSArea);
    SSSbar=nanmean(tSSSbar);
    SSTbar=nanmean(tSSTbar);

    %%%%%
    
    if (climatnumber<0 & boxnum>10) % set priors to zero
        fprintf('... box %d.\n',boxnum);
        Ffw(2,:)=max(abs(Ffw)); Ffw(1,:)=0;
        Fh(2,:)=max(abs(Fh)); Fh(1,:)=0;
        Fm(2,:)=max(abs(Fm)); Fm(1,:)=0;
        Mm(2,:)=max(abs(Mm)); Mm(1,:)=0;
        
    end;
        
    end;
    
    eval(['save airsea',num2str(boxnum), ...
        ' Ekman* F* M* SS* si_flux' ...
        ' glevels glayers gamma2 climatnumber']);
end;

% in boxes against Antarctica, increase errors 
% (see changeairsea_antbox.m)

%%% Outer Weddell
boxnum=getboxnum(0,-64,nboxes);
changeairsea_antbox;

%%% Inner Weddell, Atlantic sector
boxnum=getboxnum(-50,-72,nboxes);
changeairsea_antbox;

%%% Antarctic, Ross box
boxnum=getboxnum(-140,-70,nboxes);
changeairsea_antbox;

%%% Antarctic, Amery box
boxnum=getboxnum(110,-64,nboxes);
changeairsea_antbox;

%%% Arctic/GIN Seas box
boxnum=getboxnum(0,75,nboxes);
if (length(boxnum))
    changeairsea_antbox;
end;

%%% Med box
boxnum=getboxnum(15,35,nboxes);
if (length(boxnum))
    changeairsea_antbox;
end;
