% changeairsea_antbox.m
%
% Set the air/sea fluxes of heat and freshwater,
% and the resulting formation/transformation,
% equal to one of the climatologies.  
% In boxes against Antarctica, increase
% the errors to 200% to allow for much larger
% adjustments.  Find the layer which has the
% maximum error, and assign this error to all
% denser layers as well.  This adjustment will 
% accomodate processes such as heat loss in
% polynyas, e.g. layers with zero fluxes in the
% coarsly-gridded climatologies.
%
% This code is used by changairsea.m, which
% passes the arguments boxnum and climatnumber.
% If climatnumber=0, the ensemble mean of the
% various flux climatologies is used.

loadairseaclims
errF=2;     % error bar: 1=100 percent
errF_ek=2;  % 200% for Ekman
      
if (climatnumber>0)
    
    Ffw=[tFfw(climatnumber,:);errF*abs(tFfw(climatnumber,:))];
    q=find(Ffw(2,:)==max(Ffw(2,:)));
    Ffw(2,q(1)+1:size(Ffw,2))=Ffw(2,q(1));
    Fh=[tFh(climatnumber,:);errF*abs(tFh(climatnumber,:))];
    q=find(Fh(2,:)==max(Fh(2,:)));
    Fh(2,q(1)+1:size(Fh,2))=Fh(2,q(1));
    Fm=[tFm(climatnumber,:);errF*abs(tFm(climatnumber,:))];
    q=find(Fm(2,:)==max(Fm(2,:)));
    Fm(2,q(1)+1:size(Fm,2))=Fm(2,q(1));
    Mm=[tMm(climatnumber,:);errF*abs(tMm(climatnumber,:))];
    q=find(Mm(2,:)==max(Mm(2,:)));
    Mm(2,q(1)+1:size(Mm,2))=Mm(2,q(1));
    
    EkmanInM_range=errF_ek*abs(sum(tEkmanInM(:,:,climatnumber))');
    
    Mhek=[tMhek(climatnumber,:)];
    Mmek=[tMmek(climatnumber,:)];
    Msek=[tMsek(climatnumber,:)];
    EkmanInM=[tEkmanInM(:,:,climatnumber)];
    EkmanInH=[tEkmanInH(:,:,climatnumber)];
    EkmanInS=[tEkmanInS(:,:,climatnumber)];
    EkmanInSalt=[tEkmanInSalt(:,:,climatnumber)];
    SSArea=[tSSArea(climatnumber,:)];
    SSSbar=[tSSSbar(climatnumber,:)];
    SSTbar=[tSSTbar(climatnumber,:)];
    
else % climatnumber==0
    
    Ffw=[mean(tFfw,1);errF*abs(mean(tFfw,1))];
    q=find(Ffw(2,:)==max(Ffw(2,:)));
    Ffw(2,q(1)+1:size(Ffw,2))=Ffw(2,q(1));
    Fh=[mean(tFh,1);errF*abs(mean(tFh,1))];
    q=find(Fh(2,:)==max(Fh(2,:)));
    Fh(2,q(1)+1:size(Fh,2))=Fh(2,q(1));
    Fm=[mean(tFm,1);errF*abs(mean(tFm,1))];
    q=find(Fm(2,:)==max(Fm(2,:)));
    Fm(2,q(1)+1:size(Fm,2))=Fm(2,q(1));
    Mm=[mean(tMm,1);errF*abs(mean(tMm,1))];
    q=find(Mm(2,:)==max(Mm(2,:)));
    Mm(2,q(1)+1:size(Mm,2))=Mm(2,q(1));
    
    EkmanInM_range=errF_ek*abs(sum(EkmanInM)');
    
    Mhek=[mean(tMhek,1)];
    Mmek=[mean(tMmek,1)];
    Msek=[mean(tMsek,1)];
    EkmanInM=[mean(tEkmanInM,3)];
    EkmanInH=[mean(tEkmanInH,3)];
    EkmanInS=[mean(tEkmanInS,3)];
    EkmanInSalt=[mean(tEkmanInSalt,3)];
    SSArea=[mean(tSSArea,1)];
    SSSbar=[mean(tSSSbar,1)];
    SSTbar=[mean(tSSTbar,1)];
    
end;
    
eval(['save airsea',num2str(boxnum), ...
        ' Ekman* F* M* SS* si_flux' ...
        ' glevels glayers gamma2 climatnumber']);

