function divlayers(int_values);

% divlayers - given a desired range of gamma values,
%   and the values used in glevels (defining layer
%   interfaces), calculate the appropriate layer numbers.
%   This may include fractions of some layers, e.g.
%   if 27.68 is an upper interface, and layer 16 is between
%   27.64 and 27.71, then 0.43 percent of layer 16 
%   transport should be included (linear interpolation).

minflag=0;maxflag=0;
glev
if (min(int_values)<min(glevels))
    disp('minimum value is within layer 1.')
    disp('examine hydrography to determine appropriate percent.')
    minflag=1; 
end;
if (max(int_values)>max(glevels))
    disp('maximum value is within densest layer.')
    disp('examine hydrography to determine appropriate percent.')
    maxflag=1;
end;
l=[0 1:length(glevels) length(glevels)+1];
glevels=[min(gamma2) glevels' max(gamma2)];
l2=interp1(glevels,l,int_values,'linear');

l2=min(l2):.0001:max(l2);
fG=NaN*ones(length(glayers),1);
for i=1:length(fG);
    q=find(l2>i & l2<=i+1);
    fG(i)=length(q)*.0001;
end;

if (max(fG)<1 & length(find(fG))==1)
    fprintf('%3.3f of layer %d.\',max(fG),find(fG==max(fG)));
    return;
end;
q=find(fG);
if (fG(q(1))<1 & length(find(fG))>1)
    fprintf('%3.3f of layer %d, ',fG(q(1)),q(1));
elseif (length(find(fG))>1)
    fprintf('%d, ',q(1));
end;

q=find(fG==1);
if (length(q)==1)
    fprintf('%d',q);
elseif (length(q)>1)
    fprintf('%d-%d',min(q),max(q));
end;

q=find(fG);
if (fG(max(q))<1 & length(q)>1)
    fprintf(', %3.3f of layer %d',fG(max(q)),max(q));
end;
fprintf('\n');

return;

if length(int_values)~=2
    disp('Routine requires two values.')
    return;
end;

g1=min(int_values);
g2=max(int_values);

glev
del=(glevels-g1).^2;
if (min(del)==0)
    MinLay=find(del==0)+1;
    fMinLay=1;
else
    q=max(find(glevels<g1));
    MinLay=q+1;
    fMinLay=(glevels(q+1)-g1)/(glevels(q+1)-glevels(q));
end;
if (fMinLay<1)
    fprintf(' %3.3f of layer %d, ',fMinLay,MinLay);
else
    fprintf('layers: %d',MinLay);
end;

del=(glevels-g2).^2;
if (min(del)==0)
    MaxLay=find(del==0);
    fMaxLay=1;
else
    q=max(find(glevels<g2));
    MaxLay=q+1;
    fMaxLay=(g2-glevels(q))/(glevels(q+1)-glevels(q));
end;


q=find(glevels>g1 & glevels<g2);
if (length(q) & fMinLay<1 & fMaxLay<1)
    fprintf('%d-%d, ',min(q),max(q));
elseif (length(q) & fMinLay==1 & fMaxLay<1)
    fprintf('-%d, ',max(q));
elseif (length(q) & fMaxLay==1 & fMinLay<1)
    fprintf(', %d-',min(q));
elseif (fMaxLay==1 & fMinLay==1)
    fprintf('-');
end;

if (fMaxLay<1)
    fprintf(' %3.3f of layer %d.\n',fMaxLay,MaxLay);
else
    fprintf('%d.\n',MaxLay);
end;
