

% extract_velfield
%
% get the absolute velocity field for section "sectnum"
% Here's text that can accompany the output, when it's handed off
% to someone:

% I've extracted the velocity fields from the inverse model,
% along with some accompanying fields.  The output is saved
% for each hydrographic section, with the file name 
%   velfields_(sectionname).mat.
% Each file contains:
%   lon, lat: longitude and latitude (horizontal coordinates)
%   p, z: pressure (dbar) and depth (m) (vertical coordinates)
%   sal, temp: salinity (psu) and in-situ temperature (deg.C)
%   ugeo, uek: geostrophic and Ekman velocity (m/s).
%  Sign convention for velocity: if you're at lat(1),lon(1)
%   and looking at lat(length(lat)),lon(length(lon)),
%   then positive is to your left.  (I had to come up with a
%   more generic convention than "positive northward" because
%   of the arbitrary orientation of the sections.)
%  Total velocity is uek+ugeo.  Each velocity is for a station
%   pair, so ugeo(1) is between the pair lon(1) and lon(2).
%  Note that the Ekman transports are actually calculated from
%   monthly climatology, not from the hydrographic section.
%   I've converted the Ekman mass transport to Ekman velocities
%   assuming that they extend to a depth of 20m - totally
%   arbitrary.
%  Area: a matrix containing the area (m^2) of each bin.
%   This is NOT just the lateral distance times diff(z), for
%   bins beneath the deepest common depth of a station pair,
%   but rather the area of the bottom triangle in that bin.
%  You can calculate the mass transport as Area.*(ugeo+uek).

 
clear all; 

load gaussout sectfiles

%sectnum=sectname2sectnum('drake90');
for sectnum=1:size(sectfiles,1);
%for sectnum=20:20;     % ar19a
    

load gaussout sectlabel indv lon lat x erx nboxes;
load gaussout Ax D indb

% load reference velocity 
q=[];
for i=1:length(sectnum);
  q=[q;find(sectlabel==sectnum(i))];
end;
u_inv=x(indv(q)); eu=erx(indv(q));
%Pxx=Pxx(indv(q),indv(q));
lon=lon(q);lat=lat(q);
clear x erx

q=last(find(sectfiles(sectnum,:)=='/'));
titl=sectfiles(sectnum,q+1:size(sectfiles,2));
q=find(titl=='.');
titl=titl(1:q-1);

% load thermal wind profile gvel
eval(['load  gvel_',titl]); 
% NOTE: gvel already has uap built-in. 
eval(['load refvel_',titl,' RV']);
uap=ones(size(gvel,1),1)*RV; 
%clear RV

% special case: A8 RVs are actually zero; ref level is
% a pressure level.
if (strcmp(titl,'a08'));
  uap=zeros(size(uap));
end;

notreal=find(u_inv==0);
u_inv(notreal)=[];uap(notreal)=[];umag(notreal)=[];
lon(notreal)=[];lat(notreal)=[];
 


uref=0.*gvel+ones(size(gvel,1),1)*u_inv';  
urel=gvel;    % relative + a priori only
%%%%%%
%urel=gvel+uap; 
%%%%%%
clear gvel;
 
 
lon2=lon; lat2=lat;
% load T, S, p, lon, lat
eval(['load /WSmounts/phoddat/share/lumpkin/dobox/sections/', ...
    titl,' lat lon bin_sal bin_temp bin_press'])
p=bin_press;
temp=bin_temp;
sal=bin_sal;
clear bin*;
z=sw_dpth(p,mean(lat));

% remember that a constant velocity has been added through
% the bottom triangle.  Create a matrix called 'bottri' that
% has the value 1 where the velocity is between two casts,
% and linearly goes from 1 to 0 as you move from the deepest
% depth of the shallowest depth to the deepest depth of the deeper
% cast.  This reflects the area of the bottom triangle at that
% depth, compared to the area of a rectangle defined by the
% two casts for a given depth bin.
% assign the value 0 below the deepest cast.
bottri=ones(size(urel)); 
for i=1:size(urel,2);
    q=find(isfinite(urel(:,i)));
    bottri(max(q)+1:length(z),i)=0;
    uu=urel(q,i);
    qq=find(uu==uu(length(uu)));
    %if (max(qq)>min(qq))
    %    bottri(qq,i)=1-(qq-min(qq))/(max(qq)-min(qq)); 
    %else
        bottri(qq,i)=.5;
    %end;
end;

% keep only the non-NaN depths
uu=nansum(urel')';
q=find(uu);
uref=uref(q,:); urel=urel(q,:); 
bottri=bottri(q,:);
temp=temp(q,:); sal=sal(q,:); 
z=z(q); p=p(q);

% Calculate the box number to the left of the section
% (looking from start to finish, i.e. the "positive"
% DOBOX direction)
jumpflag=0;
if (max(abs(diff(lon)))>90) % jump across dateline
    q=find(lon<0); lon(q)=lon(q)+360; 
    jumpflag=1;
end;
dlon=[lon(1) lon(length(lon))];
dlat=[lat(1) lat(length(lat))];
lonb=mean(dlon)-min(5,.1*diff(dlat));
latb=mean(dlat)+min(5,.1*diff(dlon));
if (strcmp(titl,'drake90')) lonb=lonb-5; end;
if (strcmp(titl,'s4_atl')) latb=latb+5; end;
if (jumpflag);
    q=find(lon>180);
    lon(q)=lon(q)-360;
    if (lonb>180) lonb=lonb-360; end;
end;
boxnum=getboxnum(lonb,latb,nboxes); 
if (latb>70) boxnum=18; end;
if (0)
    plot(lon,lat,'.',lon(1),lat(1),'o',lonb,latb,'x'); 
    overlay;
    title(num2str(boxnum));
    disp('paused')
    pause;
end;


% Calculate mass transport across section 
[dx,ang]=sw_dist(lat,lon,'km');
dx=dx*1e3;  
dz=diff(z);
dz=[dz(1);dz(1:length(dz)-1)+diff(dz);dz(length(dz))];
Area=bottri.*(dz*dx);
Trel=Area.*urel;
Trel=nansum(Trel);  % sum for each stn pair
Tref=Area.*uref; 
Tref=nansum(Tref);


% get the sign of the reference transport 
pfluxref=Ax(indb(46,1,boxnum), ...
    indv(find(sectlabel==sectnum)));
uref=uref.*sign(sum(pfluxref)./sum(Tref));
Tref=Tref.*sign(sum(pfluxref)./sum(Tref));

urefadj=(pfluxref-Tref)./sum(Area); 


if (1)
% fix bottom triangle areas to be consistent with
% explicit model output.  New area is 
% A* = A + a.  (A+a)*urel = pfluxrel,
%   so pfluxrel-Trel = a*urel

pfluxrel=-D(indb(46,1,boxnum),indv(find(sectlabel==sectnum)));
%ureladj=(pfluxrel-Trel)./sum(Area);

a_times_urel=pfluxrel-Trel;
% divide by the value of urel in the bottom triangle
urel_bot=NaN*ones(1,length(lat)-1);
for m=1:length(lat)-1;
    q=find(isfinite(urel(:,m)));
    urel_bot(m)=urel(max(q),m);
end;
a=a_times_urel./urel_bot;
% this is the area to adjust the bottom triangle
bottri2=bottri;q=find(bottri==1);bottri2(q)=0;  
a2=bottri2./bottri2;
for m=1:length(lat)-1
    q=find(isfinite(a2(:,m)));
    a2(q,m)=a2(q,m)*a(m)/length(q);
end;
q=find(isnan(a2));a2(q)=0;

% a bit of sanity checking on how much this is adjusted
% from the prior Area
q=find(abs(a2)>Area);
a2(q)=sign(a2(q)).*Area(q);
     
Area=Area+a2;

%urel=urel+ones(length(p),1)*ureladj;
%uref=uref+ones(length(z),1)*urefadj;  
end;
 

% Ekman transport
load gaussout EkmanE
Tek=sum(EkmanE(:,1,boxnum,sectnum));
clear EkmanE
if (Tek==0)
    disp('WARNING: problem with boxnum?')
end;
% Assume Ekman transport is distributed over 0-20 m, 
% uniformly across the section
uek=uref./uref;
q=find(z>20);
uek(q,:)=0*uek(q,:);
uek=uek.*Tek/nansum(nansum(Area.*uek));

u=urel+uref+uek;

T=Area.*u;
q=find(isfinite(u));
T=sum(T(q))/1e6;
fprintf('Net transport across section: %3.2f Sv.\n',T);
 
ugeo=urel+uref; 

if strcmp(titl,'p03' & 0)   % get rid of artifacts over Haw.ridge at 166W
    max(max(abs(ugeo)))
    dist=sw_dist(lat,lon,'km');
    while(min(dist)<5)
        q=find(dist<5);
        for j=1:length(q);
            ugeo(:,q(j))=nanmean([ugeo(:,q(j)) ugeo(:,q(j)+1)]')';
            ugeo(:,q(j)+1)=NaN*ones(length(z),1);
            uek(:,q(j))=nanmean([uek(:,q(j)) uek(:,q(j)+1)]')';
            uek(:,q(j)+1)=NaN*ones(length(z),1);
            lat(q(j)+1)=[];
            lon(q(j)+1)=[];
            Area(:,q(j))=sum([Area(:,q(j)) Area(:,q(j)+1)]')';
            Area(:,q(j)+1)=zeros(length(z),1);
        end;
        q=find(isnan(lat));
        lat(q)=[]; lon(q)=[]; temp(:,q)=[]; sal(:,q)=[];
        q=find(nansum(Area)==0);
        Area(:,q)=[];
        ugeo(:,q)=[];
        uek(:,q)=[]; 
        dist=sw_dist(lat,lon,'km');
    end;
         
    
end;

eval(['save velfields_',titl,' ugeo uek Area lon lat temp sal z p']);

end;

