
% identify48N
%
% find the value of gamma corresponding to max(abs(Psi))
% across 48N (sectlabel==5).  The error bar is the
% range of densities bracketting this density, for which
% the net transport isn't significantly different from zero.

sectn=5;

% calculate streamfunction
Psi=sidelatflux(1,2,sectn,-1,1);
% calculate layer transports
F=sidelatflux(1,2,sectn,-1,0);

if (size(Psi,1)~=size(F,1))
  disp('Psi and F must be same size.');
  break;
end;

q=find(abs(Psi(:,1))==max(abs(Psi(:,1))) );
MagPsi=abs(Psi(q,1));
eMagPsi=abs(Psi(q,2));

% interpolate to higher res
glayers2=interp1(1:nlayers,glayers,1:.1:nlayers,'linear');
Psi2=interp1(1:nlayers,Psi(:,1),1:.1:nlayers,'linear')';
F2=NaN*ones(length(glayers2),2);
F2(:,1)=interp1(1:nlayers,F(:,1),1:.1:nlayers,'linear')';
F2(:,2)=interp1(1:nlayers,F(:,2),1:.1:nlayers,'linear')';

Psi=Psi2;clear Psi2;
F=F2; clear F2;

% find max: easy to do with simple streamfunction at 48N
mi=find(abs(Psi(:,1))==max(abs(Psi(:,1))));

% identify where F is zero within error bars
iszero=NaN*ones(size(F,1));
q=find((F(:,1)+F(:,2))>0 & ...
	(F(:,1)-F(:,2))<0);

% identify the string of contiguous q values bracketting
% the value mi
emi=[mi mi];
i=find( (q-mi).^2==min((q-mi).^2));
for j=i-1:-1:1;
  if (q(j)==q(j+1)-1) emi(1)=q(j);
  else break;
  end;
end;
for j=i+1:length(q);
  if (q(j)==q(j-1)+1) emi(2)=q(j);
  else break;
  end;
end;

% fine-tune the value of mi,
% using the interpolated F
F=abs(F(:,1)); F(1:emi(1)-1)=NaN; 
F(emi(2)+1:length(F))=NaN;
mi=find(F==min(F));

% convert glayer2 layer numbers to glayer numbers
a=(length(glayers)-1)/(length(glayers2)-1);
b=1-a;
mi=a*mi+b;
emi=a*emi+b;

% print, in table form:
% 1. ref level number
% 2. layer number of max overturning
% 3. lightest possible (2) within error bars
% 4. densest possible (2) within error bars
% 5. strength of overturning (Sv)
% 6. error on (5)
% 7. heat flux (PW)
% 8. error on 7

Hflux=calcpropflux(1:length(glayers), ...
	'ctdpotmp',2,sectn);

fprintf('\n');
fprintf('%d %2.1f %2.1f %2.1f \t %2.1f %2.1f   %2.2f %2.2f\n', ...
	reflevel(sectn),mi,emi(1),emi(2), ...
	MagPsi,eMagPsi,-Hflux(1),Hflux(2));
