% interpprop.m
%
% Using measured values of prop2 (e.g. botSILCAT2),
% corresponding to lon2, lat2, ctdpres2, 
% ctdsal2, ctdtemp2,  create a best-guess field
% prop correpsonding to lon,lat,ctdpres,ctdsal,ctdtemp.
%
% Do this by performing a simple weighted mean matching
% salt, temp and density, with a penalty in the
% weighting for increasing distance.  Don't replace
% good (non-NaN) values of prop, and use them in the
% weighted mean.

% if lon2 doesn't exist, then no additional section
% is being used, i.e. only NaNs within a section are 
% being filled using surrounding observations.
if ~exist('lon2');
  lon2=lon(1); lat2=lat(1); ctdpres2=ctdpres;
  ctdtemp2=NaN*ctdpres; ctdsal2=NaN*ctdpres;
  heads2=heads; units2=units;
  eval([property,'2=NaN*ctdpres;']);
  clear q;
end;

% extract heads2, units2 index for property
sind2=0;
for i=1:length(heads2)
  if (strcmp(char(heads2(i)), ...
	property(4:length(property)) ))
    sind2=i;
  end;
end;

eval(['S2=exist(''',property,''');'])
if S2	% property exists
  eval(['prop=',property,';']);
  sind=0;
  for i=1:length(heads)
    if (strcmp(char(heads(i)),'SILCAT'))
      sind=i;
    end;
  end;
  fprintf('These units must be consistent: ');
  fprintf(' %s  ,  %s\n',char(units(sind)), ...
	char(units2(sind2)));
  clear sind;
else
  prop=NaN*ones(size(ctdsal));
  heads=[heads,heads2(sind2)];
  units=[units,units2(sind2)];
end;
eval(['prop2=',property,'2;']);

% subsample ctdpres2 to every 12dbar
ind=1:round(12/(median(diff(ctdpres2)))):length(ctdpres2);
ctdpres2=ctdpres2(ind,:);
ctdsal2=ctdsal2(ind,:);
ctdtemp2=ctdtemp2(ind,:);
prop2=prop2(ind,:);

% include good values from prop
q=find(isfinite(nanmean(prop)));
if (length(q))
  if (size(ctdsal,1)>size(ctdsal2,1))
    zp=NaN*ones(size(ctdsal,1)- ...
	size(ctdsal2,1),size(ctdsal2,2));
    ctdtemp2=[[ctdtemp2;zp],ctdtemp(:,q)];
    ctdsal2=[[ctdsal2;zp],ctdsal(:,q)];
    prop2=[[prop2;zp],prop(:,q)];
    ctdpres2=ctdpres;
  elseif (size(ctdsal,1)<size(ctdsal2,1))
    zp=NaN*ones(size(ctdsal2,1)- ...
        size(ctdsal,1),length(q));
    ctdtemp2=[ctdtemp2,[ctdtemp(:,q);zp]];
    ctdsal2=[ctdsal2,[ctdsal(:,q);zp]];
    prop2=[prop2,[prop(:,q);zp]];
  else
    ctdtemp2=[ctdtemp2,ctdtemp(:,q)];
    ctdsal2=[ctdsal2,ctdsal(:,q)];
    prop2=[prop2,prop(:,q)];
  end;
  lon2=[lon2;lon(q)];
  lat2=[lat2;lat(q)];
end;

fprintf('Calculating gamma for %s',property);
fprintf(' regression.\n');
ctdgam=gamman(ctdsal,ctdtemp,ctdpres,lon,lat);
ctdgam2=gamman(ctdsal2,ctdtemp2,ctdpres2,lon2,lat2);

% calculate potential temp
ctdptmp=sw_ptmp(ctdsal,ctdtemp, ...
        ctdpres*ones(1,length(lon)),0);
ctdptmp2=sw_ptmp(ctdsal2,ctdtemp2, ...
        ctdpres2*ones(1,length(lon2)),0);

q=find(isfinite(ctdsal+ctdptmp+ctdgam) & ...
        isnan(prop));
lonmat2=ones(length(ctdpres2),1)*lon2';
latmat2=ones(length(ctdpres2),1)*lat2';
lonmat=ones(length(ctdpres),1)*lon';
latmat=ones(length(ctdpres),1)*lat';
glev; clear glayers glevels;
gamma2=[-999;0;gamma2;99;999];

fprintf('Interpolating %s.\n',property)
for i=1:length(q);

  laynum=min(find(gamma2>=ctdgam(q(i))));
  qq=find(ctdgam2>=gamma2(laynum-2) & ...
	ctdgam2<=gamma2(laynum+1) & isfinite(prop2));
  if (length(qq))
    Ds=std(ctdsal2(qq));
    Dt=std(ctdptmp2(qq));
    w=exp(-( ...
        ( (ctdsal2(qq)-ctdsal(q(i)))/Ds ).^2 + ...
        ( (ctdptmp2(qq)-ctdptmp(q(i)))/Dt ).^2 + ...
        ( (ctdgam2(qq)-ctdgam(q(i)))/.1 ).^2 + ...
        ( (lonmat2(qq)-lonmat(q(i)))/10 ).^2 + ...
        ( (latmat2(qq)-latmat(q(i)))/10 ).^2    ));
    if (max(max(w))>0)
      prop(q(i))=sum(prop2(qq).*w)/sum(w);
    end;
  end;
  if ~rem(i,5000)
    patchmap2(1:length(lon),-ctdpres,prop);
    colorbarvert;
    title([num2str(i),' of ',num2str(length(q))]);
    pause(.1);
  end;
end;

q=find(isnan(prop) & isfinite(ctdsal+ctdptmp));
if (length(q))
  q2=find(isnan(ctdsal));
  prop=fillnans(prop,0);
  prop(q2)=NaN;
  patchmap2(1:length(lon),-ctdpres,prop);
  colorbarvert;
end;

clear ans q qq Ds Dt i w ctdgam latmat lonmat
clear ctdptmp ctdptmp2 q2 ind
clear lon2 lat2 ctdpres2 ctdsal2 ctdtemp2 ctdgam2
clear lonmat2 latmat2 gamma2 laynum layers 
clear maxsil minsil prop2 sind2 units2 heads2 S2

eval(['clear ',property,'2;']);
eval([property,'=prop;']);
clear prop property

