function layerplot(prop,colr,plotblocks);

% function layerplot(prop,colr,plotblocks);
%
% plot property "prop" vs. gamma (neutral density)
% as defined in glev.m (glevels.mat),
% using plot style/color "colr" (e.g. ".k").
% lines (defined in waterdiv) are added for approximate 
% boundary between thermocline, intermediate, deep and
% bottom water.

if (~exist('colr'))
  colr='b';
end;
if (~exist('plotblocks'))
  plotblocks=1;
end;

glev;
if (length(prop)==length(gamma2));
  vertcoord=gamma2;
  layers=-(0:length(gamma2)-1);
elseif (length(prop)==length(glayers));
  vertcoord=glayers;
  layers=-(.5:length(glayers)-.5);
elseif (length(prop)==length(glevels));
  vertcoord=glevels;
  layers=-(1:length(glevels));
elseif (length(prop)==16);  % glayers_micom
  load layers_micom;
  glayers=glayers_micom;
  glevels=glevels_micom;
  vertcoord=glayers;
  layers=-(.5:16-.5);
else
  disp('WARNING in plotlayers.m: ')
  disp(' density coord not determined.');
  return;
end;

ytik=sort(-(5:5:length(glevels)));
ylab=num2str(round(100*glevels(-ytik))/100);

if (length(colr)~=3)
  plot(prop,layers,colr);
else 
  plot(prop,layers,'color',colr);
end;
% plot a vertical grey line at prop=0
line([0 0],[1-length(gamma2) 0], ...
        'color',[.5 .5 .5]);
set(gca,'ytick',ytik,'yticklabel',ylab);
set(gca,'ylim',[1-length(gamma2) 0]);

LatPlot=get(gca,'xlim');
set(gca,'xlim',[min(LatPlot)-.1*  ...
	range(LatPlot) max(LatPlot)]);

%%
% plot horizontal grey lines at
% water mass divisions
%%
waterdiv;
xlim=get(gca,'xlim');
for wi=1:length(waterdivs);
  divlvl=-max(find(glayers<waterdivs(wi)));
  line([-10*max(abs(prop)) 10*max(abs(prop))], ...
        [divlvl divlvl],'color',[.5 .5 .5]);
end;
set(gca,'xlim',xlim);

if (plotblocks)
% determine appropriate size for labels
P=get(gca,'pos');
fntsz=ceil( sqrt( 250*P(4) ));
% plot layers averaged in blocks
LatPlot=get(gca,'xlim');
wdth=.05*range(LatPlot);
labs=swaterdivslab;
i=1;oft=.1*wdth+wdth/2;
q=find(glayers<waterdivs(i));
patch([min(LatPlot)+oft min(LatPlot)+oft+wdth ...
         min(LatPlot)+oft+wdth min(LatPlot)+oft], ...
        [-min(q)+1 -min(q)+1 -max(q) -max(q)], ...
        [.8 .8 .8]);
text(min(LatPlot)+oft+wdth/2,-mean(q)+1,labs(i,:), ...
        'rotation',90,'horizontalalignment','center', ...
	'fontsize',fntsz);
for i=2:length(waterdivs);
  oft=.1*wdth + wdth/2*mod(i,2);
  q=find(glayers>=waterdivs(i-1) & glayers<waterdivs(i));
  patch([min(LatPlot)+oft min(LatPlot)+oft+wdth ...
         min(LatPlot)+oft+wdth min(LatPlot)+oft], ...
        [-min(q)+1 -min(q)+1 -max(q) -max(q)], ...
        [.8 .8 .8]);
  text(min(LatPlot)+oft+3*wdth/5,-mean(q)+1,labs(i,:), ...
        'rotation',90,'horizontalalignment','center', ...
        'fontsize',fntsz);
end;
q=find(glayers>=max(waterdivs));
i=i+1;oft=.1*wdth + wdth/2*mod(i,2);
patch([min(LatPlot)+oft min(LatPlot)+oft+wdth ...
       min(LatPlot)+oft+wdth min(LatPlot)+oft], ...
      [-min(q)+1 -min(q)+1 -max(q) -max(q)], ...
      [.8 .8 .8]);
text(min(LatPlot)+oft+wdth/2,-mean(q)+1,labs(i,:), ...
      'rotation',90,'horizontalalignment','center', ...
	'fontsize',fntsz);
end;	% if plotblocks
