function lev94makemprop(boxnumber);

% function lev94makemprop(boxnumber);
%
% 	(derived from getATL_intsurf.m)
% Altered to use Levitus94 instead of SAC.
%
% NOTE: for reasons related to the constant writing
% and reading associated with the gamma routines,
% this function is best run after restarting Matlab
% from scratch (do this for each box).  If the routine
% is run more than once in a session, it can produce
% the error "Could not create MLD: Not enough space"
% (related to creating the ns* files).
%
% getATL_intsurf
%
%... This file finds the mean temperature and 
%... salinity of a level surface for an inverse
%... model. It loads the relevant data from a 
%... given climatology (Levitus or SAC Hamburg).

disp('Loading geometry file "geo".');
file_geom='geo';
eval(file_geom);
nboxes=size(geometry,1);
pdir=pwd;

usrname=input('What is your user name? ','s');

glev;

% first, determine which levels *should* exist
% in the box from the bounding sections.
defined_levels=zeros(size(glevels));
q=find(abs(geometry(boxnumber,:)));
for i=1:length(q);
  eval(['load ',sectfiles(q(i),:),' surf_press']);
  surf_press=isfinite(nanmean(surf_press')');
  defined_levels=max([surf_press,defined_levels]')';
end;
clear surf_press;

clf;

% Using Levitus94 climatology
fprintf('Loading Levitus94 climatology . . . ');
load /home/lasalle0/archive/levitus94/lev_sacform

% cut data across dateline instead of 0 longitude
q=find(lon_sac>180);
lon_sac(q)=lon_sac(q)-360;
[lon_sac,ind]=sort(lon_sac);
temp_sac=temp_sac(:,:,ind);
salt_sac=salt_sac(:,:,ind);
gamma_sac=gamma_sac(:,:,ind);
fprintf('done.\n');


if (0)
  %... Use depth below the mixed layer; NaN-out all
  % values of gamma, salt, temp within m.l.
  disp('Removing mixed layer from climatology.');
  load /home/lasalle0/archive/levitus94/mixedlayer ml_sac;
  [n,m]=size(ml_sac);
  for i=1:n;
    for j=1:m;
      if (isnan(ml_sac(i,j)));
        q=1:length(depth_sac);
      else
        q=find(depth_sac<ml_sac(i,j));
      end;
      gamma_sac(q,i,j)=NaN;
      salt_sac(q,i,j)=NaN;
      temp_sac(q,i,j)=NaN;
    end;
  end;
end;
depth=depth_sac; clear depth_sac;

%... Isolate box longitude and latitude
subplot(211)
isolatesac; % output: temp, salt, gamm

if (0)
% fill NaNs in gamm for the Mediterranean
disp('filling NaNs in gamma using section ar16d')
potmp=NaN*ones(size(salt));
for i=1:size(depth);
  for j=1:size(salt,3);
    prs=(depth(i)*ones(size(salt,2),1))';
    potmp(i,:,j)=sw_ptmp(salt(i,:,j),temp(i,:,j), ...
	prs,zeros(size(salt(i,:,j))) );
  end;
end;
sigthet=sw_dens(salt,potmp,zeros(size(salt)))-1000;
load /export/lasalle1/dobox/sections/ar16d_raw bin_sigthet
load /export/lasalle1/dobox/sections/ar16d_ns gamma
q=find(gamma>0);
[p,s]=polyfit(bin_sigthet(q),gamma(q),4);
q=find(isfinite(sigthet) & gamm<0);
gamm(q)=polyval(p,sigthet(q) );
end;

% calculate the deepest value in the SAC fields
bottom_sac=NaN*ones(length(lat_sac),length(lon_sac));
for i=1:length(lat_sac);
  for j=1:length(lon_sac);
    q=find(isfinite(temp(:,i,j)));
    if (length(q))
      bottom_sac(i,j)=depth(max(q));
    end;
  end;
end;

%... calculate pressure in dbar from depth;

clear press;
press2 = sw_pres(depth*ones(1,length(lat_sac)),lat_sac');
for i = 1:length(lon_sac);
  press(:,:,i) = press2(:,:);
end
clear press2

%... find temperature and salinity values at each gamma

surf_temp=NaN*ones(length(glevels),length(lat_sac),length(lon_sac));
surf_salt=surf_temp;surf_press=surf_temp;

% change directory to the one containing the gamma routines
%usrname=input('What is your user name? ','s');
eval([ 'cd /home/lasalle/',usrname,'/matlab/gamma/matlab-interface']);

fprintf('Interpolating to find S, T, P on gamma surfaces.\n');
fprintf('  Counting to %d: \n',length(lon_sac));
for j = 1:length(lon_sac)
  fprintf(' %d',j);
  gp=gamm(:,:,j);sp=salt(:,:,j);tp=temp(:,:,j);pp=press(:,:,j);
  q=find(isnan(gp+sp+tp));gp(q)=NaN;sp(q)=NaN;tp(q)=NaN;pp(q)=NaN;
  [surf_salt(:,:,j),surf_temp(:,:,j),surf_press(:,:,j), ...
	ds,dt,dp]=neutral_surfaces(sp(:,:),tp(:,:), ...
	pp(:,:),gp(:,:),glevels);
end
fprintf('\n');

% change directory back to original
eval(['cd ',pdir])

q=find(surf_press<0 | surf_salt<0 | surf_temp==-99);
surf_press(q)=NaN;
surf_salt(q)=NaN;
surf_temp(q)=NaN;
fprintf('\n');
clear gp co ds dt dp q;

%... find area of each box.

unitlon = [0,median(diff(lon_sac))];
dy = sw_dist([0,median(diff(lat_sac))],[1,1],'km')*1000;

blat = [lat_sac(1)-median(diff(lat_sac))/2; ...
	lat_sac+median(diff(lat_sac))/2];
blat = [blat blat];

for i = 1:length(blat)
  dx(i) = sw_dist(blat(i,:),unitlon,'km')*1000;
end

dxlat = diff(dx);
area = ( dx(1:length(dx)-1) +dxlat/2 )*dy;
area = area'*ones(1,length(lon_sac));
clear dx*

%... find the area of each pixel.
% surf_area(glayers,lon,lat) [m^2]
%   is NaN where there isn't data.

blank = surf_temp./surf_temp;
area2=NaN*ones(size(blank));
for i =1:length(glevels);
  for j = 1:length(lat_sac);
    area2(i,j,:) = area(j,:);
  end
end
surf_area = area2.*blank;
clear area2 area

%... Compute the layer average area, 
% potential temperature and salinity.

%... firstly find how many non-nan data points
%... are in each level surf

%ngood_level=NaN*ones(size(glevels));
%for i = 1:length(glevels);
  %ngood_level(i) = sum(sum(finite(surf_area(i,:,:))));
%end
 
%... replace nans with zero 
%surf_press = change(surf_press,'==',NaN,0);
%surf_salt  = change(surf_salt,'==',NaN,0);
%surf_temp  = change(surf_temp,'==',NaN,0);
%surf_area  = change(surf_area,'==',NaN,0);

% calculate potential temperature
disp('Calculating potential temperature on gamma surfaces.');
surf_potmp=NaN*ones(size(surf_temp));
surf_potmp=sw_ptmp(surf_salt,surf_temp,surf_press, ...
	zeros(size(surf_press)));

% define surf_press2: equal to surf_press, but
% NaNs replaced by 0 (surface too light to exist)
% or bottom_sac value (surface is too dense).
surf_press2=surf_press;
for i=1:length(lat_sac);
  for j=1:length(lon_sac);
    q=find(isnan(surf_press2(:,i,j)));
    if (length(q))
      qq=q(find(q<length(glevels)/2));
      if (length(qq)) surf_press2(qq,i,j)=0; end;
      qq=q(find(q>length(glevels)/2));
      if (length(qq)) surf_press2(qq,i,j)=bottom_sac(i,j);end;
    end;
  end;
end;

% calculate areal averages of properties
area=NaN*ones(size(glevels));
msalt=area;mtemp=area;mpres=area;
stdsalt=area;stdtemp=area;stdpres=area;
layer_width=NaN*ones(length(glevels)+1,1);
disp('Calculating layer mean values.');
for i=1:length(glevels);
  area(i)=nansum(nansum(surf_area(i,:,:)));
  msalt(i)=nansum(nansum(surf_area(i,:,:).* ...
	surf_salt(i,:,:)))/area(i);
  mtemp(i)=nansum(nansum(surf_area(i,:,:).* ...
        surf_potmp(i,:,:)))/area(i);
  mpres(i)=nansum(nansum(surf_area(i,:,:).* ...
        surf_press(i,:,:)))/area(i);
  stdsalt(i)=nanstd(nanstd(reshape( ...
	surf_salt(i,:,:),[size(surf_salt,2) ...
	size(surf_salt,3)])));
  stdtemp(i)=nanstd(nanstd(reshape( ...
        surf_temp(i,:,:),[size(surf_temp,2) ...
        size(surf_temp,3)])));
  stdpres(i)=nanstd(nanstd(reshape( ...
        surf_press(i,:,:),[size(surf_press,2) ...
        size(surf_press,3)])));
  if (i==1)
    lwidth=surf_press2(1,:,:);	% surface to level 1
  else
    lwidth=surf_press2(i,:,:)-surf_press2(i-1,:,:);
  end;
  layer_width(i)=nanmean(lwidth(find(lwidth>0)));
end;
lwidth=bottom_sac-reshape( ...
	surf_press(length(glevels),:,:) , ...
	[length(lat_sac) length(lon_sac)]);
q=find(lwidth<=0);lwidth(q)=NaN;
layer_width(length(glevels)+1)= ...
	nanmean(lwidth(find(lwidth>0)));


% add finite (but small) areas for deep
% and shallow layers, if they don't appear
% in the SAC climatology.  For example,
% dense layers exist in the Denmark Strait
% section but not in the 1 deg. gridded
% North Atlantic SAC fields.  A finite area
% allows diapycnal fluxes in the inverse model.
origarea=area;
q=find(isnan(area) & defined_levels);
if (length(q))
  if (min(q) == min(find(defined_levels)))
    qq=q(find(q<length(glevels)/2));
    ind=min(qq):max(qq)+3;
    x=ind;y=flipud(area(ind));
    y2=fitdecay(x,y);
    area(ind)=flipud(y2);
    msalt(1:max(qq))=msalt(max(qq)+1);
    mtemp(1:max(qq))=mtemp(max(qq)+1);
    mpres(1:max(qq))=0;
    stdsalt(1:max(qq))=stdsalt(max(qq)+1);
    stdtemp(1:max(qq))=stdtemp(max(qq)+1);
    stdpres(1:max(qq))=stdpres(max(qq)+1);
  end;
  if (max(q) == max(find(defined_levels)))
    qq=q(find(q>length(glevels)/2));
    ind=min(qq)-3:max(qq);
    x=[ind,last(ind)+1];y=[area(ind);0];
    y2=fitdecay(x,y);
    area(ind)=y2(1:length(ind));
    msalt(qq)=msalt(qq(1)-1);
    mtemp(qq)=mtemp(qq(1)-1);
    mpres(qq)=mpres(qq(1)-1);
    stdsalt(qq)=stdsalt(qq(1)-1);
    stdtemp(qq)=stdtemp(qq(1)-1);
    stdpres(qq)=stdpres(qq(1)-1);
  end;
  if (min(q)>min(find(defined_levels)) & ...
	 max(q)<max(find(defined_levels)))
    qq=find(isfinite(area));
    area(q)=interp1(glevels(qq),area(qq), ...
	glevels(q),'linear');
    msalt(q)=interp1(glevels(qq),msalt(qq), ...
	glevels(q),'linear');
    mtemp(q)=interp1(glevels(qq),mtemp(qq), ...
	glevels(q),'linear');
    mpres(q)=interp1(glevels(qq),mpres(qq), ...
	glevels(q),'linear');
    stdsalt(q)=interp1(glevels(qq),stdsalt(qq), ...
	glevels(q),'linear');
    stdtemp(q)=interp1(glevels(qq),stdtemp(qq), ...
        glevels(q),'linear');
    stdpres(q)=interp1(glevels(qq),stdpres(qq), ...
        glevels(q),'linear');
  end;
end;

% now fix layer widths to be consistent with
% the changes in level areas, assuming conservation
% of volume and equipartition of layer width.
origlayer_width=layer_width;
w=interp1(glayers,layer_width,glevels,'linear');
q=find(area~=origarea & isfinite(area));
if (length(q))
  qq=q(find(q<length(glevels)/2));
  if (length(qq))
    V=nansum(w(qq).*origarea(qq));
    w(qq)=V./nansum(area(qq));
  end;
  qq=q(find(q>length(glevels)/2));
  if (length(qq))
    V=nansum(w(qq).*origarea(qq));
    w(qq)=V./nansum(area(qq));
  end;
end;
nlayer_width=[w(1);w(1:length(w)-1)+diff(w)/2;last(w)];
q=find(isnan(layer_width));
layer_width(q)=nlayer_width(q);

layer_area=[area(1); ...
	area(1:length(area)-1)+diff(area)/2; ...
	last(area)];

subplot(211);
plot(origarea,'r'); hold on;
plot([min(find(defined_levels)) ...
  min(find(defined_levels))],[0 max(area)]);
plot([max(find(defined_levels)) ...
  max(find(defined_levels))],[0 max(area)]);
plot(area,'.k');
hold off;
title('Level areas (corrected: points)')
subplot(212);
plot(origlayer_width,'r');hold on;
plot(layer_width,'.k');hold off;
title('Layer widths (corrected: points)');
pause(5);
%disp('Paused; enter "dbcont" to continue.');
%keyboard;

%... save layer averages

%filename = input('box number (for filename suffix): ','s');
filename=num2str(boxnumber);
modelname='atl';

svar = [' msalt_',modelname,filename];
tvar = [' mtemp_',modelname,filename]; 
avar = [' area_',modelname,filename];
pvar = [' mpres_',modelname,filename];
svar2= [' stdsalt_',modelname,filename];
tvar2= [' stdtemp_',modelname,filename];
pvar2= [' stdpres_',modelname,filename];
zvar2= [' layer_width_',modelname,filename];
zvar3= [' layer_area_',modelname,filename];

eval([svar '=msalt;']);
eval([tvar '=mtemp;']);
eval([avar '=area;']);
eval([pvar '=mpres;']);
eval([svar2 '=stdsalt;']);
eval([tvar2 '=stdtemp;']);
eval([pvar2 '=stdpres;']);
eval([zvar2 '=layer_width;']);
eval([zvar3 '=layer_area;']);

eval(['save mprop_',modelname,filename svar tvar avar pvar ...
	svar2 tvar2 pvar2 zvar2 zvar3 ' lat_sac lon_sac ']);

% plot results
subplot(234);
plot(mtemp,-mpres,mtemp+stdtemp,-mpres,'r', ...
	mtemp-stdtemp,-mpres,'r');title('Temp')
subplot(235);
plot(msalt,-mpres,msalt+stdsalt,-mpres,'r', ...
	msalt-stdsalt,-mpres,'r');title('Salt');
subplot(236);
plot(area/1e12,-mpres);title('Area');

pause(1);

clear all;
