% loadairseaclims
%
% this routine loops through all "nclim" climatologies
% of air-sea fluxes for box "boxnum", loading their
% output from makeairsea.m and storing this output
% in vectors such as "tEkmanInM".
% The routine then assigns the mean of all "nclim"
% climatologies for each layer, and the range of
% all climatologies as the error.
%
% Because the individual climatologies are retained
% in the t* vectors, this information can be used
% to create new airsea*.mat files for an inversion
% using only one of the original climatologies
% (see "changeairsea.m", which uses this routine)

nclims=5; % number of climatologies

load airsea_1_1 EkmanInH
tEkmanInH=NaN*ones([size(EkmanInH) nclims]);
tEkmanInM=tEkmanInH;
tEkmanInS=tEkmanInH;
tEkmanInSalt=tEkmanInH;
tFfw=NaN*ones([nclims length(glayers)]);
tFh=tFfw;
tFm=NaN*ones([nclims length(gamma2)]);
tMhek=NaN*ones([nclims length(glayers)]);
tMm=tMhek; tMmek=tMhek; tMsek=tMhek;
tSSArea=tMhek; tSSSbar=tMhek; tSSTbar=tMhek;

for climnum=1:nclims;
  eval(['load airsea_',num2str(climnum), ...
	'_',num2str(boxnum), ...
	' EkmanIn* F* M* SS* si_flux']);
  tEkmanInH(:,:,climnum)=EkmanInH;
  tEkmanInM(:,:,climnum)=EkmanInM;
  tEkmanInS(:,:,climnum)=EkmanInS;
  tEkmanInSalt(:,:,climnum)=EkmanInSalt;
  tFfw(climnum,:)=Ffw(1,:);
  tFh(climnum,:)=Fh(1,:);
  tFm(climnum,:)=Fm(1,:);
  tMhek(climnum,:)=Mhek(1,:);
  tMm(climnum,:)=Mm(1,:);
  tMmek(climnum,:)=Mmek(1,:);
  tMsek(climnum,:)=Msek(1,:);
  tSSArea(climnum,:)=SSArea;
  tSSSbar(climnum,:)=SSSbar;
  tSSTbar(climnum,:)=SSTbar;
end;

EkmanInH=mean(tEkmanInH,3);
EkmanInM=mean(tEkmanInM,3);
EkmanInS=mean(tEkmanInS,3);
EkmanInSalt=mean(tEkmanInSalt,3);
EkmanInM_range=sum(tEkmanInM,1);
EkmanInM_range=reshape(EkmanInM_range, ...
	[size(tEkmanInM,2) nclims]);
EkmanInM_range=range(EkmanInM_range')';

% error bars: assign range/2
Ffw=[mean(tFfw);range(tFfw)/2];
Fh=[mean(tFh);range(tFh)/2];
Fm=[mean(tFm);range(tFm)/2];
Mm=[mean(tMm);range(tMm)/2];

Mhek=mean(tMhek);
Mmek=mean(tMmek);
Msek=mean(tMsek);
SSArea=nanmean(tSSArea);
SSSbar=nanmean(tSSSbar);
SSTbar=nanmean(tSSTbar);


