
function makesacsecction(section)

% function makesacsecction(section)
%
% extract the mean temperature, salinity,
% and oxygen from the SAC/Hamburg climatology
% for the station pairs in WOCE section
% "section.mat".  
% Save the result as "sectionsac.mat".

dir_sac='/phod007/lumpkin/sac';

if (0);
    eval(['load ',section,' lon lat ', ...
        'expocode st_order stnnbr']);
else
    lon=(-50.1:.25:17.1)';
    lat=-30*ones(size(lon));
    expocode='fake';st_order=(1:length(lon))';
    stnnbr=st_order;
    section='sac30s';
end;
fprintf('Loading SAC/Hamburg climatology ... ');
eval(['load ',dir_sac,'/sac lon_sac lat_sac ', ...
	' temp_sac salt_sac depth_sac oxy_sac bottom_sac']);

% cut across dateline instead of 0 longitude
q=find(lon_sac>180);
lon_sac(q)=lon_sac(q)-360;
[lon_sac,ind]=sort(lon_sac);
temp_sac=temp_sac(:,:,ind);
salt_sac=salt_sac(:,:,ind);
oxy_sac=oxy_sac(:,:,ind);
bottom_sac=bottom_sac(:,:,ind);

q=find(lon_sac>min(lon)-1 & lon_sac<max(lon)+1);
lon_sac=lon_sac(q);
temp_sac=temp_sac(:,:,q);
salt_sac=salt_sac(:,:,q);
oxy_sac=oxy_sac(:,:,q);
bottom_sac=bottom_sac(:,:,q);

q=find(lat_sac>min(lat)-1 & lat_sac<max(lat)+1);
lat_sac=lat_sac(q);
temp_sac=temp_sac(:,q,:);
salt_sac=salt_sac(:,q,:);
oxy_sac=oxy_sac(:,q,:);
bottom_sac=bottom_sac(:,q,:);

ctdpres=(0:2:max(depth_sac))';
ctdtemp=NaN*ones(length(ctdpres),length(lon));
ctdsal=ctdtemp;ctdoxy=ctdtemp;
bottom=NaN*ones(size(lon));

fprintf('interpolating ... ');
% interpolation scheme: nearest neighbor
% for lat, lon (or NaNs will always extract
% the shallowest depth); linear vertically.
for i=1:length(lon);
    del=(lat_sac-lat(i)).^2;
    latind=find(del==min(del));
    del=(lon_sac-lon(i)).^2;
    lonind=find(del==min(del));
    
    bottom(i)=bottom_sac(1,latind,lonind);
    ctdtemp(:,i)=interp1(depth_sac, ...
        temp_sac(:,latind,lonind),ctdpres','linear')';
    ctdsal(:,i)=interp1(depth_sac, ...
        salt_sac(:,latind,lonind),ctdpres','linear')';
    ctdoxy(:,i)=interp1(depth_sac, ...
        oxy_sac(:,latind,lonind),ctdpres','linear')';
end;
% fill with constant temp, salt, oxy from deepest 
% non-NaN value to the bottom
%for i=1:length(lon);
%    q=find(isnan(ctdtemp(:,i)) & ctdpres<bottom(i));
%    ctdtemp(q,i)=last(ctdtemp(isfinite(ctdtemp(:,i)),i));
%    q=find(isnan(ctdsal(:,i)) & ctdpres<bottom(i));
%    ctdsal(q,i)=last(ctdsal(isfinite(ctdsal(:,i)),i));
%    q=find(isnan(ctdoxy(:,i))&ctdpres<bottom(i));
%    ctdoxy(q,i)=last(ctdoxy(isfinite(ctdoxy(:,i)),i));
%end;

% remove observations below deepest value of ctdpres
deepest=nanmean((ctdtemp+ctdsal)')';
deepest=ctdpres(last(find(isfinite(deepest))));
q=find(ctdpres>deepest+10);
ctdpres(q)=[];
ctdsal(q,:)=[];
ctdtemp(q,:)=[];
ctdoxy(q,:)=[];

clear del latind lonind i *sac q ind 

% create other variables which are standard
% for a WOCE section file
time=NaN*ones(size(lon));
heads=cellstr('NOTHING');
units=cellstr('NOTHING');
botNOTHING=ones(size(ctdtemp));
clear i q

fprintf('saving %ssac.mat\n',section);
eval(['save ',section,'sac']);