function pcolor2(x,y,z,numdec,N);

% function pcolor2(x,y,z,numdec,N);
%
% make a pcolor plot, shaded flat with a color
% range set by the histrogram of the z values
% (so that closely-spaced values in one part of
% the range won't be as saturated).
%
% numdec: number of sig. fig.'s shown in colorbar.
% N: number of bins in color histogram.

q=find(isfinite(z));
if ~length(q)
  disp('No valid (non-NaN) values.');
  break;
end;

if (~exist('numdec'))
  numdec=2;
end;
if (~exist('N'))
  N=100;
end;

% add the last row and column of z
dx=abs(median(diff(x)));
dy=abs(median(diff(y)));
[n,m]=size(x);
if (m==1) x=x'; end;
[n,m]=size(y);
if (m==1) y=y'; end;
if (y(length(y))>y(1))  % min values at beginning
  yrev=0;
  yy=y;
else
  yrev=1;
  yy=fliplr(y);
end;
y=yy(1:length(yy)-1)+diff(yy)/2;
y=[yy(1)-(yy(2)-yy(1))/2,y,yy(length(yy))+ ...
        (yy(length(yy))-yy(length(yy)-1))/2];
if (yrev)
  y=fliplr(y);
end;
if (x(length(x))>x(1))  % min values at beginning
  xrev=0;
  xx=x;
else
  xrev=1;
  xx=fliplr(x);
end;
x=xx(1:length(xx)-1)+diff(xx)/2;
x=[xx(1)-(xx(2)-xx(1))/2,x,xx(length(xx))+ ...
        (xx(length(xx))-xx(length(xx)-1))/2];
if (xrev)
  x=fliplr(x);
end;
[i,j]=size(z);
z=[[z;NaN*ones(1,j)],NaN*ones(i+1,1)];

% calculate histogram
q=find(isfinite(z));
[n,val]=hist(z(q),N);
q=find(~n);
n(q)=[];val(q)=[];
dval=median(diff(val));
val2=[val(1)-dval/2, ...
	val(1:length(val)-1)+dval/2];
l=[];
for i=1:length(val2)-1;
  dv=(val2(i+1)-val2(i))/(N*n(i)/sum(n));
  v=val2(i):dv:val2(i+1);
  l=[l,v];
end;
z2=NaN*ones(size(z));
for i=1:length(l)-1;
  q=find(z>l(i) & z<=l(i+1));
  z2(q)=i;
end;
q=find(z>max(l));
z2(q)=length(l);
q=find(z<min(l));
z2(q)=1;

pcolor(x,y,z2);
shading flat;

for i=1:2;
po=get(gca,'pos');
opo=po;
asp=get(gca,'plotboxaspectratio');
if (asp(2)>asp(1))
  x=[po(1) po(1)+po(3)];
  xbar=mean(x);
  x=(x-x(1))*asp(1)/asp(2);
%%%%%
x=.6*x;
  x=x-mean(x)+xbar;
  po(1)=x(1);
  x=x-mean(x)+xbar;
  po(1)=x(1);
  po(3)=x(2)-x(1);
else
  y=[po(2) po(2)+po(4)];
  ybar=mean(y);
  y=(y-y(1))*asp(2)/asp(1);
%%%%%%
y=.6*y;
  y=y-mean(y)+ybar;
  po(2)=y(1);
  po(4)=y(2)-y(1);
end;
ch1=colorbar;
set(gca,'pos',opo);
set(ch1,'pos',[.01+po(1)+po(3) po(2) ...
        .02 po(4)],'fontsize',8);
end;

dtick=round(N/5);
legtick=l(1:dtick:length(l))';
set(ch1,'ytick',1:dtick:length(l));
form=['%10.',num2str(numdec),'f'];
legend=num2str(legtick,form);
set(ch1,'yticklabel',legend);

