
% plotairsea
%
% plot the corrected air-sea fluxes of buoyancy,
% heat and freshwater for box BoxNum along with the climatologies

%BoxNum=13;

gamlim=[24 28];
colorplot=0;		% set to 0 for b&w, 1 for color

clf;

symbols={'--' ...  % UWM/COADS
    '.' ... % SOC unadjusted
    '-.' ... % SOC adjusted
    ':' ... % NCEP
    '-'};   % ERA-15
colors=[[1 0 0];[1 0 1];[1 1 0];[0 0 1];[0 1 1]];

% load the raw climatologies
Nclim=5;
tFm=NaN*ones(Nclim,length(glayers)+1);
tFfw=NaN*ones(Nclim,length(glayers));
tFh=tFfw;
for i=1:Nclim;
    eval(['load airsea_',num2str(i),'_', ...
            num2str(BoxNum),' Fm Ffw Fh']);
    tFm(i,:)=Fm(1,:);
    tFfw(i,:)=Ffw(1,:);
    tFh(i,:)=Fh(1,:);
end;
eval(['load airsea',num2str(BoxNum),' Fm Ffw Fh']);


% calculate the mean conversion factor as a function
% of layer
FluxDivFact=NaN*ones(nlayers-1,nboxes);
for boxnum=BoxNum:BoxNum;
  S=meanprop(:,2,boxnum)*1000+35;
  Th=meanprop(:,3,boxnum);
  eval(['load mprop_atl',num2str(boxnum), ...
        ' mpres_atl',num2str(boxnum)]);
  eval(['P=mpres_atl',num2str(boxnum),';']);
  T=sw_temp(S,Th,P,zeros(size(P)));
  Rho=sw_dens(S,T,P);
  Cp=sw_cp(S,T,P);
  FluxDivFact(:,boxnum)=1e15./Rho./Cp;
end;
fluxdivfact=fillnans(FluxDivFact(:,BoxNum),0);
fluxdivfact_lay=fillnans(interp1(glevels, ...
        FluxDivFact(:,BoxNum),glayers),0);

for boxnum=BoxNum:BoxNum;

  %eval(['load airsea',num2str(boxnum),' t*']);
  fdens=(Fdens(2:nlayers,boxnum)+ ...
	Fdenscorr(2:nlayers,boxnum))/1e6;
  efdens=eFdenscorr(2:nlayers,boxnum)/1e6;

  ffw=x(indF(:,2,boxnum));
  effw=erx(indF(:,2,boxnum));
  ffw=ffw/1e3; effw=effw/1e3;

  fh=x(indF(:,1,boxnum));
  efh=erx(indF(:,1,boxnum));
  fh=fh./fluxdivfact;efh=efh./fluxdivfact;

  % by construction in gauss.m, each layer gets 1/2 of the
  % flux from the lighter level and 1/2 from the heavier level.
  ffw=[0;ffw;0];ffw=ffw(1:length(ffw)-1)+diff(ffw)/2;
  fh=[0;fh;0];fh=fh(1:length(fh)-1)+diff(fh)/2;
  effw_lay=NaN*ones(size(glayers));efh_lay=effw_lay;
  effw_lay(1)=effw(1)/2;effw_lay(length(glayers))=last(effw)/2;
  efh_lay(1)=efh(1)/2;efh_lay(length(glayers))=last(efh)/2;
  for i=2:length(glayers)-1;
    effw_lay(i)=sqrt( effw(i-1)^2 + effw(i)^2)/sqrt(2);
    efh_lay(i)=sqrt( efh(i-1)^2 + efh(i)^2)/sqrt(2);
  end;
  efh=efh_lay;effw=effw_lay;

  % add a priori air-sea fluxes
  ffw=ffw+AirSea(:,1,boxnum)/1e3;
  fh=fh+AirSea(:,3,boxnum)./fluxdivfact_lay;
  
  
  % plot the fluxes

  subplot(3,1,1);
  set(gca,'fontsize',12);
  plot(glevels,fdens,'k','linewidth',2);
  hold on;
  line([min(gamma2) max(gamma2)],[0 0],'color',[.5 .5 .5]);
  patch([glevels;flipud(glevels)], ...
        [fdens+efdens ; flipud(fdens-efdens)], ...
        [.7 .7 .7],'edgecolor','none');
  plot(glevels,fdens,'k','linewidth',2);
  for i=1:Nclim;
      plot(gamma2,tFm(i,:)/1e6, [char(symbols(i)), 'k'], ...
          'linewidth',1);
  end;
  hold off;
  set(gca,'xlim',[min(gamlim) max(gamlim)]);

  subplot(3,1,2);
  set(gca,'fontsize',12);
  plot(glayers,ffw);
  hold on;
  line([min(gamma2) max(gamma2)],[0 0],'color',[.5 .5 .5]);
  text(25,max(ffw+effw),['Net: ', ...
          num2str(sum(ffw),'%3.0f'),'m^3/s']);
  if (colorplot)
    patch([glayers;flipud(glayers)], ...
	[ffw+effw ; flipud(ffw-effw)], ...
        [.5 1 .5],'edgecolor','none');
    plot(glayers,ffw,'color',[0 .5 0]);
    for i=1:Nclim;
        plot(glayers,tFfw(i,:)/1e3,'--', ...
	    'linewidth',1,'color',colors(Nclim,:));
    end;
  else
    patch([glayers;flipud(glayers)], ...
        [ffw+effw ; flipud(ffw-effw)], ...
        [.7 .7 .7],'edgecolor','none');
    plot(glayers,ffw,'k','linewidth',2);
    for i=1:Nclim;
        plot(glayers,tFfw(i,:)/1e3, [char(symbols(i)), 'k'], ...
          'linewidth',1);
    end;
  end;

  hold off;
  set(gca,'xlim',[min(gamlim) max(gamlim)]);
  %title('F_{fw} (green: a priori, black: corrected)');

  subplot(3,1,3);
  set(gca,'fontsize',12);
  plot(glayers,fh,'r');
  hold on;
  line([min(gamma2) max(gamma2)],[0 0],'color',[.5 .5 .5]);
  text(25,max(fh+efh),['Net: ', ...
          num2str(sum(fh),'%3.2f'),'PW']);
  if (colorplot)
    patch([glayers;flipud(glayers)], ...
	[fh+efh; flipud(fh-efh)], ...
        [1 .7 .7],'edgecolor','none');
    plot(glayers,fh,'r');
    for i=1:Nclim
        plot(glayers,tFh(i,:)./fluxdivfact_lay', ...
	    '--','linewidth',1,'color',colors(Nclim,:));
    end;
  else
    patch([glayers;flipud(glayers)], ...
        [fh+efh ; flipud(fh-efh)], ...
        [.7 .7 .7],'edgecolor','none');
    plot(glayers,fh,'k','linewidth',2);
    for i=1:Nclim;
        plot(glayers,tFh(i,:)./fluxdivfact_lay', ...
            [char(symbols(i)), 'k'], ...
          'linewidth',1);
    end;
  end;
  hold off;
  set(gca,'xlim',[min(gamlim) max(gamlim)]);

end;	% loop over boxes

subplot(3,1,1);
ylabel('F_\rho (Sv)','fontsize',15);
subplot(3,1,2);
ylabel('F_{fw} (10^3 m^3/s)','fontsize',15);
subplot(3,1,3);
ylabel('F_h (PW)','fontsize',15);

subplot(3,1,1);
%title(boxlabels(boxnum,:),'fontsize',15);
subplot(3,1,3);
xlabel('\gamma^n','fontsize',15);

orient landscape
load gaussout fluxdivfact

