
% plotdiaflux.m
%
% Plot the diapycnic flux across levels using the
% output of gauss.m, for property number
% "propnum" and box "boxnum".

% set plotanomaly=1 to plot the diapycnal flux
% driven purely by the w* terms for that property;
% set to zero for the net subsurface (i.e. non-F)
% diapycnal flux.  There is no difference for volume.

plotanomaly=1;
includeapriori=1;
if ~exist('plotblocks') plotblocks=1; end;

% calculate the mean conversion factor as a function
% of layer
FluxDivFact=NaN*ones(nlayers-1,nboxes);
for bn=1:nboxes;
  S=meanprop(:,2,bn)*1000+35;
  Th=meanprop(:,3,bn);
  eval(['load mprop_atl',num2str(bn), ...
        ' mpres_atl',num2str(bn)]);
  eval(['P=mpres_atl',num2str(bn),';']);
  T=sw_temp(S,Th,P,zeros(size(P)));
  Rho=sw_dens(S,T,P);
  if (propnum==1) fluxdivfact=1e6*ones(size(glevels));
  elseif (propnum==2)
    fluxdivfact=1e6./Rho;
  elseif (propnum==3)
    Cp=sw_cp(S,T,P);
    fluxdivfact=1e15./Rho./Cp;
  end;
  FluxDivFact(:,bn)=fluxdivfact;
end;
fluxdivfact=fillnans(nanmean(FluxDivFact')',0);

drD(:,1)=x(indw(:,propnum,boxnum)).* ...
	meanprop_nonans(:,propnum,boxnum).* ...
	level_area_nonans(:,boxnum);
if (includeapriori)
  drD(:,1)=drD(:,1)+drD_ap(2:nlayers,propnum,boxnum);
end;

% include flux from buoyancy advection
if (propnum>1 & ~plotanomaly)
  drD(:,1)=drD(:,1)+x(indw(:,1,boxnum)).* ...
	meanprop_nonans(:,propnum,boxnum).* ...
	level_area_nonans(:,boxnum);
  if (propnum==2)
    drD(:,1)=drD(:,1)+35/1000* ...
	x(indw(:,1,boxnum)).* ...
        level_area_nonans(:,boxnum);
  end;
  if (propnum==2 & includeapriori)
    drD(:,1)=drD(:,1)+35/1000* ...
	drD_ap(2:nlayers,1,boxnum);
  end;
end;

% smooth the curve
if (0)
set(gca,'fontsize',10)
drD2=drD;
for i=2:length(drD)-1
    drD2(i)=(drD(i-1)+2*drD(i)+drD(i+1))/4;
end;
drD=drD2; clear drD2;
end;    % if smoothing

cumerror=NaN*ones(nlayers-1,1);
for i=nlayers-1:-1:1;
  if (plotanomaly | propnum==1)
    h=A(indb(i,propnum,boxnum), ...
        indw(i,propnum,boxnum))';
    cumerror(i)=sqrt(  sum(sum(h'* ...
        Pxx(indw(i,propnum,boxnum), ...
        indw(i,propnum,boxnum)) *h))  );
  elseif (~plotanomaly & propnum==2)
    h=A(indb(i,1,boxnum),indw(i,1,boxnum))';
    cumerror(i)=35/1000*sqrt(  sum(sum(h'* ...
        Pxx(indw(i,1,boxnum), ...
        indw(i,1,boxnum)) *h))  );
  else
    h=A(indb(i,propnum,boxnum), ...
        indw(i,[1 propnum],boxnum))';
    cumerror(i)=sqrt(  sum(sum(h'* ...
        Pxx(indw(i,[1 propnum],boxnum), ...
        indw(i,[1 propnum],boxnum)) *h))  );
  end;
end;
drD(:,2)=cumerror;

w=drD(:,1)./fluxdivfact;
werr=drD(:,2)./fluxdivfact;

er=1:length(glevels);er=er';
plot(w,-er);
hold on;
patch([w+werr;flipud(w-werr)], ...
      [-er;flipud(-er)],[.7 .7 .7], ...
      'edgecolor','none');
set(gca,'xlim',[1.2*min(w-werr) 1.2*max(w+werr)]);
layerplot(w,'k',plotblocks);
hold off;
title(['subsurface diapycnal flux (',propnames(propnum,:),', box ', ...
	num2str(boxnum),')']);
xlabel(fluxunits(propnum,:));

%clear w werr drD;
load gaussout fluxdivfact;
