
% plotlatflux: visualize output from gauss.m
%
% Plot the lateral (isopycnic) property fluxes across the
% sections for water mass "massnum", including the Ekman flux.
% In each box, state the air-sea and mixing generation
% rates of the water mass.
% Water mass "massnum" is defined in waterdiv.m.
% If "massnum" is negative, plot the flux in glayers(massnum)

holdstatus=ishold;

%for propnum=3:3;

latisekman=0;		% set to 1 for Ekman flux only
latisvref=0;		% set to 1 for reference flux only
latisvrel=0;		% set to 1 for relative flux only
latisapriori=0;		% set to 1 for rel+Ek only
latisgeost=0;       % set to 1 for geostrophic only (Ekman=0)

plotanom=0;		% set to 1 for salt anomaly (propnum=2)
			% set to 0 for salt (incl. Sbar flux)
			% set to 1 for heat anomaly wrt Tbar
%Tbar=meanprop(9,3,2);	% reference temp for heat anomaly
Tbar=0;
labelflux=1;		% set to 1 for transport labels (eg. 1.0+-0.6)
labeldia=1;		% set to 1 for mixing, airsea labels
barwidth=5;

colorplot=1;		% set to 1 for color plot (using propcolor),
			% 	 0 for black & white plot

if ~exist('propcolr')
    disp('loading gaussout.mat')
  load gaussout;
end;
if (colorplot)
  tpropcolr=propcolr;
else
  tpropcolr=[[0 0 0];[.5 .5 .5];[0 0 0]];
end;

tempsectlabel=sectlabel;
tempgeometry=geometry;
if (1)  %combine for single 24N trans-Atlantic
    q=find(tempsectlabel==sectname2sectnum('a05fs'));
    if (length(q))
        tempsectlabel(q)=sectname2sectnum('a05int');
    end;
end;
if (1)  % single GIS section
    q=find(tempsectlabel==sectname2sectnum('ar18e1'));
    if (length(q))
        tempsectlabel(q)=sectname2sectnum('ice2scot');
    end;
end
if (1)  % single S4 section
    q=find(tempsectlabel==sectname2sectnum('s4_atl'));
    if (length(q))
        tempsectlabel(q)=sectname2sectnum('s4_pac');
    end;
    q=find(tempsectlabel==sectname2sectnum('s4_ind'));
    if (length(q))
        tempsectlabel(q)=sectname2sectnum('s4_pac');
    end;
end

tempnsections=size(tempgeometry,2);

if (~exist('massnum')) massnum=0; end;

if (propnum==1)
  multfact=1; legendflux=1; numstr='%2.1f'; lq2=1.5;
  if (massnum<0) multfact=2; legendflux=10/multfact; end;
  if (massnum==0) multfact=.5; end;
elseif (propnum==2)
   if (massnum>0)
        multfact=.1; legendflux=30; numstr='%2.1f'; lq2=2.5;
    else
        multfact=.01; legendflux=30; numstr='%2.1f'; lq2=2.5;
    end;
else
  multfact=15; legendflux=.5; numstr='%2.2f'; lq2=2;
end;

waterdiv;		% define the layers.

if (massnum<0 & length(massnum)==1)
  titl=['layer ',num2str(-massnum)];
  nlyr=-massnum;
elseif (massnum<0)
  titl=['layers ',num2str(-(max(massnum))), ...
        '-',num2str(-(min(massnum)))];
  nlyr=-massnum;
elseif (massnum==0)
  titl='net';
  nlyr=1:length(glayers);
elseif (massnum==1)
  titl=waterdivslab(massnum,:);
  nlyr=find(glayers<waterdivs(massnum));
elseif (massnum==length(waterdivs)+1)
  titl=waterdivslab(massnum,:);
  nlyr=find(glayers>=last(waterdivs));
elseif (massnum>1 & massnum<length(waterdivs)+1)
  titl=waterdivslab(massnum,:);
  nlyr=find(glayers>=waterdivs(massnum-1) & ...
	glayers<waterdivs(massnum));
end;

% calculate the mean conversion factor as a function
% of layer
FluxDivFact=NaN*ones(nlayers,nboxes);
for boxnum=1:nboxes;
  S=meanprop(:,2,boxnum)*1000+35;
  Th=meanprop(:,3,boxnum);
  eval(['load mprop_atl',num2str(boxnum), ...
        ' mpres_atl',num2str(boxnum)]);
  eval(['P=mpres_atl',num2str(boxnum),';']);
  T=sw_temp(S,Th,P,zeros(size(P)));
  Rho=sw_dens(S,T,P);
  if (propnum==1) fluxdivfact=1e6*ones(size(glevels));
  elseif (propnum==2)
      fluxdivfact=1e6./Rho;
  elseif (propnum==3)
    Cp=sw_cp(S,T,P);
    fluxdivfact=1e15./Rho./Cp;
  end;
  FluxDivFact(:,boxnum)=fillnans(interp1(glevels, ...
      fluxdivfact,glayers),0);
end;
fluxdivfact=mean(FluxDivFact,2);

%%%%%%%%%%%%%%%%%%%
%disp('WARNING: changed fluxdivfact for debugging')
%fluxdivfact=1e6*ones(size(fluxdivfact));
%%%%%%%%%%%%%%%%%%%

% Calculate the lateral flux latflux(boxnum,sectnum,1)
% across each section in layer "massnum".
% This flux is composed of the total geostrophic
% flow (relative + reference) and the Ekman flow.
% latflux(boxnum,sectnum,2) contains the std errors.
latflux=zeros(nboxes,tempnsections,2);
for boxnum=1:nboxes;

  % EXAMPLE HERE OF ELLIPSES CHANGE: BREAK LINE BEFORE DIFF
  %meanp=[meanp(1);meanp(1:length(meanp)-1)+diff(meanp)/2;last(meanp)];

  for sectnum=1:tempnsections;

    q=find(tempsectlabel==sectnum);
    if (length(q))
    pfluxref=sum(Ax(indb(nlyr,propnum,boxnum),indv(q)),2);

    if (exist('indE') )
      h=A(indb(nlyr,propnum,boxnum), ...
	[indv(q);indE(unique(sectlabel(q)))])';
      h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
      eref=sum(sum(h'*Pxx( ...
	  [indv(q);indE(unique(sectlabel(q)))], ...
	  [indv(q);indE(unique(sectlabel(q)))])*h));
    else	% no correction to Ekman
      h=A(indb(nlyr,propnum,boxnum),indv(q))';
      h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
      eref=sum(sum(h'*Pxx(indv(q),indv(q))*h));
    end;
    eref=sqrt(eref);

    pfluxrel=-sum(D(indb(nlyr,propnum,boxnum),indv(q)),2);
    EkIn=EkmanE(nlyr,propnum,boxnum,sectnum);

    if (propnum==3 & plotanom==1)
      pfluxref=pfluxref - Tbar*sum( ...
	Ax(indb(nlyr,1,boxnum),indv(q)),2);
      pfluxrel=pfluxrel + Tbar*sum( ...
	D(indb(nlyr,1,boxnum),indv(q)),2);
      EkIn=EkIn-Tbar.*EkmanE(nlyr,1,boxnum,sectnum);
    end;

    if (propnum==2 & ~plotanom)
      pfluxref=pfluxref+35/1e3* ...
	sum(Ax(indb(nlyr,1,boxnum),indv(q)),2);
      h=35/1000*A(indb(nlyr,1,boxnum),indv(q))';
      h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
      eref2=sum(sum(h'*Pxx(indv(q),indv(q))*h));
      eref2=sqrt(eref2);
      eref=sqrt(eref^2+eref2^2);
      pfluxrel=pfluxrel-35/1e3* ...
	sum(D(indb(nlyr,1,boxnum),indv(q)),2);
      EkIn=EkIn+35/1e3*EkmanE(nlyr,1,boxnum,sectnum);
    end;

    pfluxref=pfluxref./fluxdivfact(nlyr);
    pfluxrel=pfluxrel./fluxdivfact(nlyr);
    EkIn=EkIn./fluxdivfact(nlyr);

    latflux(boxnum,sectnum,1)=sum(pfluxref+pfluxrel+EkIn);
    latflux(boxnum,sectnum,2)=eref;
    if (latisekman)
      disp('Plotting Ekman flux only')
      latflux(boxnum,sectnum,1)=sum(EkIn);
      latflux(boxnum,sectnum,2)=0;
    elseif (latisvref)
      disp('Plotting reference flux only')
      latflux(boxnum,sectnum,1)=sum(pfluxref);
    elseif (latisvrel)
      disp('Plotting relative flux only')
      latflux(boxnum,sectnum,1)=sum(pfluxrel);
      latflux(boxnum,sectnum,2)=0;
    elseif (latisapriori)
      disp('Plotting a priori only')
      latflux(boxnum,sectnum,1)=sum(pfluxrel+EkIn);
      latflux(boxnum,sectnum,2)=0;
    elseif (latisgeost)
        disp('Plotting geostrophic only')
        latflux(boxnum,sectnum,1)=sum(pfluxref+pfluxrel); 
    end;

    end;	% if length(q)
  end;
end;

% Calculate the diapycnal advection ("vertflux")driven by
% the air-sea buoyancy flux and subsurface mixing of density.
% For propnum=1, vertflux=airsea_adv+mixing.
% For propnum>1, this is not true because of the diffusive
% 	terms in "mixing"
vertflux=NaN*ones(nboxes,2);
for boxnum=1:nboxes;
  if ~(plotanom==1 & propnum==3)
    vflux=diff(W(:,boxnum) ...
	.*[0;level_area_nonans(:,boxnum);0] ...
	.*[0;meanprop_nonans(:,propnum,boxnum);0]) ...
	./fluxdivfact;
  else % plotanom==1 & propnum==3
    vflux=diff(W(:,boxnum) ...
        .*[0;level_area_nonans(:,boxnum);0] ...
        .*([0;meanprop_nonans(:,propnum,boxnum);0]-Tbar)) ...
        ./fluxdivfact;
  end;
  vertflux(boxnum,1)=sum(vflux(nlyr));
  h=A(indb(nlyr,propnum,boxnum), ...
        [indF(:,:,boxnum),indw(:,propnum,boxnum)])';
  h=h./(ones(size(h,1),1)*fluxdivfact(nlyr)');
  eref=sum(sum(h'*Pxx( ...
	[indF(:,:,boxnum),indw(:,propnum,boxnum)], ...
	[indF(:,:,boxnum),indw(:,propnum,boxnum)])*h));
  vertflux(boxnum,2)=sqrt(eref);

end;

% calculate airsea(boxnumber,1), a vector containing
% the direct air-sea input of the property, and
% the input from diapycnal advection driven by
% the air-sea buoyancy flux.
% airsea(boxnumber,2) are the std errors.
% separately calculate airsea_dir(boxnumber), the
% direct air-sea input, and airsea_adv(boxnumber),
% the advective component driven by the buoyancy flux.
airsea=zeros(nboxes,2);
airsea_dir=airsea;airsea_adv=airsea;
for boxnum=1:nboxes;

  fdens=(Fdens(2:nlayers,boxnum)+ ...
        Fdenscorr(2:nlayers,boxnum));
  ffw=x(indF(:,2,boxnum));
  fh=x(indF(:,1,boxnum));
  % interpolate ffh, fh to glayers grid
  ffw=[0;ffw;0];ffw=ffw(1:length(ffw)-1)+diff(ffw)/2;
  fh=[0;fh;0];fh=fh(1:length(fh)-1)+diff(fh)/2;

  % direct input
  airsea(boxnum,1)=sum(AirSea(nlyr,propnum,boxnum) ...
	./fluxdivfact(nlyr));
  % include adjustments
  if (propnum==1)	% fw adjustment
    airsea(boxnum,1)=airsea(boxnum,1)+ ...
	sum(ffw(nlyr)./fluxdivfact(nlyr));
  elseif (propnum==3)	% heat adjustment
    airsea(boxnum,1)=airsea(boxnum,1)+ ...
	sum(fh(nlyr)./fluxdivfact(nlyr));
  end;
  airsea_dir(boxnum,1)=airsea(boxnum,1);

  % air-sea driven diapycnal advective convergence
  if ~(plotanom==1 & propnum==3)
    w_as=-fdens.*meanprop_nonans(:,propnum,boxnum);
    w_as=[0;w_as;0];
    w_as_conv=diff(w_as);
    airsea(boxnum,1)=airsea(boxnum,1)+ ...
	sum(w_as_conv(nlyr)./fluxdivfact(nlyr));
    airsea_adv(boxnum,1)= ...
	sum(w_as_conv(nlyr)./fluxdivfact(nlyr));
  else	% (plotanom==1 & propnum==3)
    w_as=-fdens.*(meanprop_nonans(:,propnum,boxnum)-Tbar);
    w_as=[0;w_as;0];
    w_as_conv=diff(w_as);
    airsea(boxnum,1)=airsea(boxnum,1)+ ...
        sum(w_as_conv(nlyr)./fluxdivfact(nlyr));
    airsea_adv(boxnum,1)= ...
        sum(w_as_conv(nlyr)./fluxdivfact(nlyr));
  end;

  h=A(indb(nlyr,propnum,boxnum),indF(:,:,boxnum))';
  h=h ./ (ones(size(h,1),1)*fluxdivfact(nlyr)');
  eref=sqrt(sum(sum(h'*Pxx( ...
	indF(:,:,boxnum),indF(:,:,boxnum))*h)));
  airsea(boxnum,2)=eref;
  airsea_adv(boxnum,2)=eref;	%should be advective only!!
  if (propnum==1)
    nlvl=max(1,min(nlyr)-1): ...
        min(length(glevels),max(nlyr));
    h=Pxx(indF(nlvl,2,boxnum),indF(nlvl,2,boxnum));
    h=h(find(isfinite(h)));
    eref=sqrt(sum(h))/mean(fluxdivfact(nlyr));
    airsea_dir(boxnum,2)=eref;
  elseif (propnum==2)
    airsea_dir(boxnum,2)=0;
  else
    nlvl=max(1,min(nlyr)-1): ...
	min(length(glevels),max(nlyr));
    h=Pxx(indF(nlvl,1,boxnum),indF(nlvl,1,boxnum));
    h=h(find(isfinite(h)));
    eref=sqrt(sum(h))/mean(fluxdivfact(nlyr));
    airsea_dir(boxnum,2)=eref;
  end;

end;	% loop through boxes

% define mixing(boxnum,1), a matrix
% containing the diapycnic flux convergence
% (advective and mixing; same units as
% isopycnal flux).
% mixing(boxnum,2) contains the std error.
mixing=NaN*ones(nboxes,2);
ermixing=mixing;
for boxnum=1:nboxes;

  % by including all property indices in indw,
  % this should include both diffusive w* terms and
  % diapycnal advection terms
  mixing(boxnum,1)=sum(sum(Ax(indb(nlyr,propnum,boxnum), ...
        indw(:,:,boxnum)),2) ./fluxdivfact(nlyr));
  if (plotanom==1 & propnum==3)
    Wmix=[0;x(indw(:,1,boxnum)).*level_area_nonans(:,boxnum).* ...
        (meanprop_nonans(:,propnum,boxnum)-Tbar);0];
    % include diffusive term - DON'T remove this, as it is
    % an absolute flux (not defined WRT 0degC) similar to
    % the air-sea heat flux
    Wmix=Wmix+[0;x(indw(:,propnum,boxnum)).* ...
        level_area_nonans(:,boxnum).* ...
        meanprop_nonans(:,propnum,boxnum);0];
    Wmix_conv=diff(Wmix);
    mixing(boxnum,1)=sum(Wmix_conv(nlyr)./fluxdivfact(nlyr));
  end;

  % include a priori mixing
  if (includemixing_ap)
    w_mix_conv=diff(drD_ap(:,propnum,boxnum));
    mixing(boxnum,1)=mixing(boxnum,1)+ ...
        sum(w_mix_conv(nlyr)./fluxdivfact(nlyr));
    if (plotanom==1 & propnum==3)
       w_mix_conv=diff(drD_ap(:,1,boxnum));
       mixing(boxnum,1)=mixing(boxnum,1)-Tbar* ...
        (sum(w_mix_conv(nlyr)./fluxdivfact(nlyr)));
    end;
  end;

  h=A(indb(nlyr,propnum,boxnum),indw(:,:,boxnum))';
  h=h ./ (ones(size(h,1),1)*fluxdivfact(nlyr)');
  eref=sqrt(sum(sum(h'*Pxx( ...
        indw(:,:,boxnum),indw(:,:,boxnum))*h)));
  mixing(boxnum,2)=eref;
end;

if (~ishold)	% first-time through loops: make map
  %clf;
  minlon=min([min(lon)-10 -100]);
  maxlon=max([max(lon)+10 0]);
  minlat=min(lat)-10;
  maxlat=max(lat)+5;
  if (range(lon)<20 & range(lat)<20)
      minlon=min(lon)-1;maxlon=max(lon)+1;
      minlat=min(lat)-1;maxlat=max(lat)+1;
  end;
  %makemap_merc([minlon maxlon], ...
	%[min(lat)-10 max(lat)+5],0,1);
  %hold on;
  plot(lon(1),lat(1),'.k','markersize',1);
  hold on; 
  if (max(lat)<28 & min(lat)>25 & ...
          max(lon)<-74 & min(lon)>-90)
      tlon=lon;tlat=lat;
    load bathyabaco;
    contour(lon,lat,z,[0 0],'k');
    colormap(flipud(bone));
    lon=tlon;lat=tlat;
    multfact=.01*multfact;
  else
    overlay([.75 .75 .75]);
  end;
  axis([minlon maxlon minlat maxlat]);
end;

lonF=NaN*ones(tempnsections,1);
latF=lonF;
for boxnum=1:nboxes;
  for sectnum=1:tempnsections;
    if (tempgeometry(boxnum,sectnum));
      q=find(tempsectlabel==sectnum);
      lq=floor(length(q)/3);
      if (lq>1)
        qq=q( round((lq2-1)*lq+1:lq2*lq));
      else qq=q; 
      end;
      if (length(q))
      plot(lon(q),lat(q),'.', ...
	'markersize',4,'color',[.5 .5 .5]);
      lonF(sectnum)=lon(round(median(qq)));
      latF(sectnum)=lat(round(median(qq)));
      thetaF=median(theta(q));
      Fx=-[latflux(boxnum,sectnum,1)*sin(thetaF) ...
	*tempgeometry(boxnum,sectnum) 0];
      Fy=[latflux(boxnum,sectnum,1)*cos(thetaF) ...
	*tempgeometry(boxnum,sectnum) 0];
      eFx=-[latflux(boxnum,sectnum,2)*sin(thetaF) ...
        *tempgeometry(boxnum,sectnum) 0];
      eFy=[latflux(boxnum,sectnum,2)*cos(thetaF) ...
        *tempgeometry(boxnum,sectnum) 0];

      P=quiver([lonF(sectnum) 0], ...
	[latF(sectnum) 0], ...
	multfact*Fx,multfact*Fy,0,'.');
        set(P,'color',tpropcolr(propnum,:), ...
		'linewidth',barwidth);

      % superimpose very light grey bar for heat flux;
      % make it shorter and a bit offset, so it's bordered
      % by black.
      if (propnum==3 & ~colorplot)
	spc=.025;
        P=quiver([lonF(sectnum) 0]+spc*multfact*Fx, ...
        [latF(sectnum) 0]+spc*multfact*Fy, ...
        (1-2*spc)*multfact*Fx,(1-2*spc)*multfact*Fy,0,'.');
        set(P,'color',[.9 .9 .9], ...
                'linewidth',.7*barwidth);
      end;
        
      if (labelflux)
        labl=[num2str(abs(latflux(boxnum,sectnum,1)),numstr), ...
	'\pm',num2str(latflux(boxnum,sectnum,2),numstr)];
        text(lonF(sectnum)+multfact*Fx(1)+2, ...
	  latF(sectnum)+.9*multfact*Fy(1),labl,'fontsize',10);
      end;
      end;
    end;
  end;
end;
title(titl,'fontsize',15);

% add legend
if (propnum==1)
  legend=[-65,-15];        % center of legend
elseif (propnum==2);
  legend=[-65,5];        % center of legend
else
  legend=[-65,-5];
end;

dx=15; dy=7;            % width, height (degrees)
%patch([legend(1)-dx/2 legend(1)-dx/2 ...
        %legend(1)+dx/2 legend(1)+dx/2], ...
        %[legend(2)-dy/2 legend(2)+dy/2 ...
        %legend(2)+dy/2 legend(2)-dy/2],'w');
H=fill([legend(1)-dx/2 legend(1)-dx/2 ...
        legend(1)+dx/2 legend(1)+dx/2], ...
        [legend(2)-dy/2 legend(2)+dy/2 ...
        legend(2)+dy/2 legend(2)-dy/2],'w');
P=quiver([legend(1)-multfact*legendflux/2 0], ...
	[legend(2)+dy/5 0],multfact*[legendflux 0],[0 0],0,'.');
set(P,'color',tpropcolr(propnum,:),'linewidth',barwidth);
if (propnum==3 & ~colorplot)
  spc=.025;
  P=quiver([legend(1)-multfact*legendflux/2 0]+ ...
        spc*multfact,[legend(2)+dy/5 0], ...
	(1-3*spc)*multfact*[legendflux 0],[0 0],0,'.');
  set(P,'color',[.9 .9 .9],'linewidth',.7*barwidth);
end;

if (propnum==2)
  text(legend(1),legend(2)-dy/4, ...
        [num2str(legendflux),'x10^6 kg/s'], ...
        'horizontalalignment','center','fontsize',10);
else
  text(legend(1),legend(2)-dy/4, ...
	[num2str(legendflux),fluxunits(propnum,:)], ...
        'horizontalalignment','center','fontsize',10);
end;

if (labeldia)
for boxnum=1:nboxes;
  
  q=find(tempgeometry(boxnum,:)~=0);
  lonB=(max(lonF(q))+min(lonF(q)))/2;
  latB=(max(latF(q))+min(latF(q)))/2;
  %%%% box-specific tweaks
  if (min(lonF(q))<0 & max(lonF(q)>120)) % Pac wraparound
      lonB=-125;
  end;

  % label how much of the property is removed/added from
  % the layers by diapycnal flux divergence in each box
  str=['Mixing: '];
  if (mixing(boxnum,1)>0.05) str=[str,'+'];
  end;
  str=[str,num2str(mixing(boxnum,1),numstr)];
  str=[str,' \pm ',num2str(mixing(boxnum,2),numstr)];
  str=[str,fluxunits(propnum,:)];
  if (massnum)
    H=text(lonB,latB+2,str,'fontsize',8, ...
	'horizontalalignment','center');
    set(H,'fontangle','italic');
  end;

  % label how much of the property is removed/added by
  % air-sea fluxes.
  str=['Air-sea (direct): '];
  if (airsea_dir(boxnum,1)>0.05) str=[str,'+']; end;
  str=[str,num2str(airsea_dir(boxnum,1),numstr)];
  str=[str,' \pm ',num2str(airsea_dir(boxnum,2),numstr)];
  str=[str,fluxunits(propnum,:)];
  H=text(lonB,latB-1,str,'fontsize',8, ...
	'horizontalalignment','center');
  set(H,'fontangle','italic');

  if (abs(airsea_adv(boxnum,1))>.001)
    str=['Air-sea (adv): '];
    if (airsea_adv(boxnum,1)>0.05) str=[str,'+']; end;
    str=[str,num2str(airsea_adv(boxnum,1),numstr)];
    str=[str,' \pm ',num2str(airsea_adv(boxnum,2),numstr)];
    str=[str,fluxunits(propnum,:)];
    H=text(lonB,latB-4,str,'fontsize',8, ...
        'horizontalalignment','center');
    set(H,'fontangle','italic');
  end;
  
end;
end;

% display values of lateral fluxes
fprintf(['Lateral fluxes (',fluxunits(propnum,:),'):\n']);
fprintf('  Sect:\t');
for l=1:tempnsections;
  fprintf(['     ',num2str(l),'\t\t']);
end;
fprintf('\n');
for boxnum=1:nboxes;
  fprintf('Box %d: \t',boxnum);
  for l=1:tempnsections;
    if (propnum~=3)
      fprintf('%3.1f +- %3.1f\t', ...
        latflux(boxnum,l,1),latflux(boxnum,l,2));
    else	% heat: 2 decimal places
      fprintf('%3.2f +- %3.2f\t', ...
        latflux(boxnum,l,1),latflux(boxnum,l,2));
    end;
  end;
  fprintf('\n');
end;

%end;	% loop through propnum

if (holdstatus);
  hold on;
else
  hold off;
end;

if (latisvref);
  load gaussout AirSea;
end;

load gaussout_control fluxdivfact;
