function plotrefvels(sectnum);

% plotrefvels(sectnum);
%
% plot the reference velocities from the inverse
% model solution for section number "sectnum".
%  Lt. grey bullets with error bars: a priori.
%   Asterisks with dark grey error bars: a posteriori.

load gaussout sectlabel indv lon lat x erx Pxx sectfiles;
q=[];
for i=1:length(sectnum);
  q=[q;find(sectlabel==sectnum(i))];
end;
u=100*x(indv(q));eu=100*erx(indv(q));
Pxx=Pxx(indv(q),indv(q));
lon=lon(q);lat=lat(q);

notreal=find(u==0);

uap=[];umag=[];
for i=1:length(sectnum)
  q=last(find(sectfiles(sectnum(i),:)=='/'));
  titl=sectfiles(sectnum(i),q+1:size(sectfiles,2));
  q=find(titl=='.');
  titl=titl(1:q-1);

  eval(['load refvel_',titl]);
  uap=[uap;RV'*100];
  umag=[umag;Vmag'*100];
end;

% special case: A8 RVs are actually zero; ref level is
% a pressure level.
if (strcmp(titl,'a08'));
  uap=zeros(size(uap));
end;

u=u+uap;

u(notreal)=[];uap(notreal)=[];umag(notreal)=[];
lon(notreal)=[];lat(notreal)=[];

difflat=max(lat)-min(lat);
difflon=max(lon)-min(lon);
if (difflon>difflat)
  horvar=lon';
  horlab='longitude';
else
  horvar=lat';
  horlab='latitude';
end;

if (last(horvar)<horvar(1))
  horvar=fliplr(horvar);
  u=-flipud(u);eu=flipud(eu);Pxx=flipud(fliplr(Pxx));
  uap=-flipud(uap);umag=flipud(umag);
end;

pts=3;	% number of points for running mean
u2=NaN*ones(length(u)-pts+1,1); eu2=u2;
x=1:length(u);
for i=1:length(u)-pts+1;
  u2(i)=mean(u(i:i+pts-1));
  x2(i)=mean(x(i:i+pts-1));
  l=Pxx(i:i+pts-1,i:i+pts-1);
  l=l(find(l<9e99));
  eu2(i)=sqrt(sum(l))/length(l)*100;
end;

dkgrey=[.5 .5 .5];
ltgrey=[.8 .8 .8];

plot(x,u,'.');
hold on;
plot(x,uap,'.','markersize',30,'color',ltgrey);
for i=1:length(x)
  line([x(i) x(i)],[uap(i)+umag(i) uap(i)-umag(i)], ...
	'color',ltgrey,'linewidth',2);
end;
patch([x2,fliplr(x2)]',[u2+eu2;flipud(u2-eu2)], ...
	dkgrey,'edgecolor','none');
line([0 max(x)+1],[0 0],'color',[.25 .25 .25]);
plot(x,uap,'o','markersize',10,'color',ltgrey);
plot(x,u,'*k','markersize',10);
hold off;
xtiks=1:round(length(horvar)/5):length(horvar);
xlabs=num2str(abs(round(10*horvar(xtiks)')/10));
xlabs=[xlabs,setstr(176)*ones(size(xlabs,1),1)];
if (last(horvar)<horvar(1));
  xlabs=flipud(xlabs);
end;
set(gca,'xtick',xtiks,'xticklabel',xlabs);
axis([0 max(x)+1 min(u-.5*umag) max(u+.5*umag)]);
xlabel(horlab);
ylabel('cm/s');

title(titl);
grid on;

