function [z,z2]=plotsect(x,z,C,zU,zS,col,wdth);

% function [z,z2]=plotsect(x,z,C,zU,zS,col,wdth);
%
% Create a pcolor2 image as a function of x (horizontal
% units) by z (vertical units, e.g. dbar or m).
% The surfacemost zU (default=500 z units) is stretched
% to fill a fraction zS (default=.3) of the vertical
% limits of the plot.
%
% This function should work if C is a property
% with dimension (length(z),length(x)) or if
% C is a matrix of depths with dimension (N,length(x)).
% In the latter case, lines of C are plotted using
% color "col", linewidth "wdth".
%
% Rick Lumpkin 10 Sept 2001

isheld=ishold;

zW=.05;	% size of white space between z<zU and z>zU

if length(z)==size(z,1) z=z'; end;

if ~exist('zU')
  zU=500;
end;
if ~exist('zS')
  zS=.3;
end;
if ~exist('col')
  col='k';
end;
if ~exist('wdth')
  wdth=1;
end;

% make sure z is defined positive for 
% increasing depth
if (max(z)<=0)
  z=-z; zU=abs(zU);
end;

% rescale z
if (max(z)>2*zU);
  q=find(z<=zU);
  z2=0:zS/(length(q)-1):zS;
  q=find(z>zU);
  zt=zS:(1-zS)/(length(q)-1):1;
  z2=[z2,zt];
else
  z2=z;
end;

% now add a row of NaNs just below zU
% and stretch z2 by zW
q=find(z>=zU);q=q(1);
a=(1-zW-zS)/(1-zS); b=zW/(1-zS);
z=[z(1:q-1),z(q),z(q)+.1,z(q+1:length(z))];
z2=[z2(1:q-1),z2(q), ...
        z2(q:length(z2))*a+b];

if (size(C,1)==length(z)-1)
  C=[C(1:q-1,:);NaN*ones(2,size(C,2)); ...
	C(q+1:size(C,1),:)];
  pcolor2(x,-z2,C);
else	% C is a matrix of N-by-length(lon) z values
  if (max(max(C))<=0)
    C=-C;
  end;
  q=find(isfinite(C));
  C(q)=interp1(z,z2,C(q),'linear');
  plot(x,-C,'color',col,'linewidth',wdth);
end;

x1=get(gca,'xlim');x2=x1(2);x1=x1(1);
hold on;
patch([x1 x1 x2 x2],[-zS-zW -zS -zS -zS-zW],'w', ...
	'edgecolor',[.2 .2 .2]);

% define vertical tick marks
if zU<=200
  tiks=[0:50:zU];
else 
  tiks=[0:100:zU];
end;
tiks=[tiks,zU+.1,1000*ceil(zU/1000):1000:max(z)];
% if zU>=1000, this produces one value which
% must be removed
q=find(diff(tiks)<0);
if (length(q)) tiks(q+1)=[]; end;

tiks2=NaN*ones(size(tiks));
for i=1:length(tiks2);
  q=find(z>=tiks(i));
  tiks2(i)=min(q);
end;
set(gca,'ytick',-fliplr(z2(tiks2)));
set(gca,'yticklabel',num2str(round(fliplr(tiks)')));
set(gca,'tickdir','out');

if ~isheld 
  hold off;
end;

