function plotsection(sectnum,includeVref);

% function plotsection(sectnum,includeVref);
%
% Plot the T, S and relative geostrophic
% velocity of a section (listed in geo.m)
% which has been prepared via Dobox.
% 
% If includeVref==1 (default is 0), load
% the output of gaussout.mat and include
% reference velocities in the vel. plot

clf;

if (~exist('includeVref'));
  includeVref=0;
end;

geo;	% load directory name
load gaussout reflevel
sectfiles=sectfiles(sectnum,:);
q=find(sectfiles=='.');
sectfiles(q:length(sectfiles))=[];
eval(['load ',sectfiles,'_raw']);
eval(['load ',sectfiles,'_ns']);
% load gvel_* file
q=find(sectfiles=='/');
q=last(q);
sectfiles(1:q)=[];
eval(['load gvel_',sectfiles]);
reflevel=reflevel(sectnum);

maxz=nansum(bin_sal')';
q=find(isfinite(maxz));
maxz=max(bin_press(q))+100;
if (maxz>2000);
  ytiks=-500*round(maxz/500):500:0;
else
  ytiks=-250*round(maxz/250):250:0;
end;
ylabs=num2str(abs(ytiks'));

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot the section location
%%%%%%%%%%%%%%%%%%%%%%%%%%%

subplot(221)

plot(lon,lat,'color',[.5 .5 .5]);
hold on;
plot(lon(1),lat(1),'.k','markersize',5);
hold off;
overlay;
axis([min(lon)-10 max(lon)+10, ...
	min(lat)-10 max(lat)+10]);
londist=sw_dist([mean(lat) mean(lat)], ...
        [min(lon)-10 max(lon)+10],'km');
latdist=sw_dist([min(lat)-10 max(lat)+10], ...
        [mean(lon) mean(lon)],'km');
set(gca,'dataaspectratio', ...
        [latdist*(range(lon)+20) londist*(range(lat)+20) 1]);
ttl=sectfiles;
for i=1:length(ttl);
  if (ttl(i)=='_') ttl(i)='-'; end;
end;
title(ttl,'fontsize',15);

difflat=max(lat)-min(lat);
difflon=max(lon)-min(lon);
if (difflon>difflat)
  horvar=lon;
else
  horvar=lat;
end;
horvar2=horvar(1:length(horvar)-1) ...
	+diff(horvar)/2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot geostrophic velocities
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

subplot(222);
if (includeVref);
  load gaussout sectlabel x indv;
  x=x(indv(find(sectlabel==sectnum)));
  gvel=gvel+ones(length(bin_press),1)*x';
end;

%q=find(horvar2<-35);q2=find(bin_press>2000);
%min(min(gvel(q2,q))  )
%keyboard

xtiks=1:round(length(horvar)/10):length(horvar);
xlabs=num2str(abs(round(10*horvar(xtiks)')/10));
xlabs=[xlabs,setstr(176)*ones(length(xlabs),1)];
if (last(horvar)<horvar(1));
  xlabs=flipud(xlabs);
end;

if (last(horvar2)>horvar2(1))
  indx=1.5:length(horvar2)+.5;
else
  indx=length(horvar2)+.5:-1:1.5;
end;
lon2=lon(1:length(lon)-1)+diff(lon)/2;
lat2=lat(1:length(lat)-1)+diff(lat)/2;
pcolor2(indx,-bin_press,gvel);
%patchmap2(indx,-bin_press,gvel);
axis([1 length(horvar) -maxz 0]);
if (reflevel>0);
  hold on;
  plot([indx-.5 last(indx)+.5], ...
	-surf_press(reflevel,:),'k', ...
        'linewidth',1.5);
  hold off;
  titl=['Ref. level \gamma^n = ',num2str(glevels(reflevel)), ...
        ', mean depth ', ...
        num2str(round(nanmedian(surf_press(reflevel,:)))), ...
        ' m'];
else
  titl='Ref. level: deepest common depth';
end;
set(gca,'xtick',xtiks,'xticklabel',xlabs, ...
	'ytick',ytiks,'yticklabel',ylabs,'fontsize',6);
title(titl,'fontsize',10);
% calculate net mass transport from reference
% velocity across each stn pair
delx=1000*sw_dist(lon,lat,'km');
delz=median(diff(bin_press));

M=gvel*delz.*(ones(length(bin_press),1)*delx);
M=nansum(nansum(M))/1e6;
M=round(10*M)/10;
% Mass flux: positive to the left
% (if section is zonal, and bulleted first value
%  is at the western edge, then a positive flux 
%  is northward).
if (includeVref)
  titl=['  Net mass flux: ',num2str(M),' Sv'];
else
  titl=['  Relative mass flux: ',num2str(M),' Sv'];
end;
%text(min(horvar),-maxz/2,titl);
disp(titl);


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot salinity
%%%%%%%%%%%%%%%%%%%%%%%%%%%

subplot(223);
if (last(horvar)>horvar(1))
  indx=1:length(horvar);
else
  indx=length(horvar):-1:1;
end;
pcolor2(indx,-bin_press,bin_sal);
axis([min(indx) max(indx) -maxz 0]);
set(gca,'xtick',xtiks,'xticklabel',xlabs, ...
        'ytick',ytiks,'yticklabel',ylabs,'fontsize',6);
title('Salinity','fontsize',10)
if (reflevel>0);
  hold on;
  plot(indx,-surf_press(reflevel,:),'k', ...
        'linewidth',1.5);
  hold off;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot potential temperature
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

subplot(224);
pcolor2(indx,-bin_press,bin_potmp);
axis([1 length(horvar) -maxz 0]);
set(gca,'xtick',xtiks,'xticklabel',xlabs, ...
        'ytick',ytiks,'yticklabel',ylabs,'fontsize',6);
title('\theta_0','fontsize',10)

if (0)
  % flux in stations stnnbr, in pressure range pr
  stnnbr=[1:6];pr=[1900 5000];
  q=find(bin_press>min(pr) & bin_press<max(pr));
  M=gvel(q,stnnbr)*delz.* ...
	(ones(length(bin_press(q)),1)*delx(stnnbr));
  M=nansum(nansum(M))/1e6;
  M=round(10*M)/10
  max(max(abs(gvel(q,stnnbr))))
end;
