function plotsections(sm,cart)

% function plotsections(sm,cart)
%
% Plot all the sections in file "geo.m",
% adding labels giving the section names.
% If sm=0 (default), do not include section
% names or starting points.
% If cart=1 (default), plot in cartesian
% coords (i.e. don't use m_map routines)

col='k';    % color
overlayflag=0;  % set to 1 for overlay

if ~exist('sm') sm=0; end;
if ~exist('cart') cart=1; end;

if cart
  plotcom='plot';
  textcom='text';
else
  plotcom='m_plot';
  textcom='m_text';
end;

%geofile=input('Geometry file name? ','s');
%eval(geofile);
geo;

Lon=[];Lat=[];
for i=1:size(geometry,2);
  eval(['load ',sectfiles(i,:),' lon lat']);
  Lon=[Lon;lon'];Lat=[Lat;lat'];
  q=find(Lon<-180);Lon(q)=Lon(q)+360;
  q=find(Lon>180);Lon(q)=Lon(q)-360;
end;

hld=ishold;
if ~hld clf; end;
minlon=min([-100 min(Lon)-10]);
if (~cart)
  %makemap([minlon max(Lon)+10], ...
	%[min(Lat)-10 max(Lat)+10],0,1);
    makemap([-180 180],[-10 -90],0,1)
else
    plot(1,1,'.w','markersize',1);
end;

hold on;
for i=1:size(geometry,2);	% loop through sections
  eval(['load ',sectfiles(i,:),' lon lat']);

  % detect sections wrapping around dateline
  q=find(abs(diff(lon))>180);
  while(length(q))
    lon=[lon(1:q(1)),NaN,lon(q(1)+1:length(lon))];
    lat=[lat(1:q(1)),NaN,lat(q(1)+1:length(lat))];
    q=find(abs(diff(lon))>180);
  end;
  if length(lon) 
     eval([plotcom,'(lon,lat,''',col,''')']); 
  end;
  if sm
    eval([plotcom,'(lon(1),lat(1),''.'',''markersize'',5);']);
    % define median positions on section
    lon=lon+1e-9*rand(size(lon));
    lon2=lon(isfinite(lon));
    if (mod(length(lon2),2))
      lon2=lon2(1:length(lon2)-1);
    end;
    ind=find(lon2>=nanmedian(lon2));
    mlon=lon2(ind(1));mlat=lat(ind(1));

    name=sectfiles(i,:);
    q=find(name=='/');
    name(1:max(q))=[];
    q=find(name=='.');
    name(min(q):length(name))=[];
    eval([textcom,'(mlon,mlat,name,''fontsize'',10,', ...
	'''horizontalalignment'',''center'');']);
  end;
end;
if (cart & overlayflag);
  overlay;
elseif ~cart
  m_coast('line','color',[0 .5 0]);
  %m_grid('xticklabels',[],'yticklabels',[]);
end;

if (~hld) hold off; end;

clear hld lon lat mlon mlat name q;

