% smith_sand_bottom.m
%
% calculate the depth of the water column
% and its variations at positions specified
% by vectors lon, lat.  The "surrounding 
% neighborhood" of each point is extracted,
% using the spacing between each point.
%
% The output is smith_sand_bottom(length(lon),3).
% The first column is the mean depth, weighted
% by distance from the position lon, lat.
% The second column is the minimum depth
% (possibly >0) in the area surrounding 
% (lon, lat), the third column is the max depth.
%
% R. Lumpkin, 14 June 2002.

clf;

subplot(211);
plot(lon,lat,'.');
hold on;
lon2=lon;q=find(lon<0);
lon2(q)=lon2(q)+360;

smith_sand_bottom=NaN*ones(length(lon),3);
if length(lat)==size(lat,1)
  lat=lat';lon=lon';bottom=bottom';
end;
dlat=abs(diff(lat));
dlon=abs(diff(lon));
dlon2=abs(diff(lon2));
q=find(dlon>100);
dlon(q)=dlon2(q);
clear *lon2;
dlat=[dlat(1),dlat(1:length(dlat)-1)+ ...
	diff(dlat)/2,last(dlat)];
dlon=[dlon(1),dlon(1:length(dlon)-1)+ ...
	diff(dlon)/2,last(dlon)];
del=sqrt(dlat.^2+dlon.^2);

for i=1:length(lon);
  fprintf('%d of %d\n ',i,length(lon));
  minlon=max([lon(i)-del(i)/2 -180]);
  maxlon=min([lon(i)+del(i)/2 180]);
  minlat=max([lat(i)-del(i)/2 -71.999]);
  maxlat=min([lat(i)+del(i)/2 71.999]);
  plot([minlon maxlon maxlon minlon minlon], ...
	[minlat minlat maxlat maxlat minlat],'k');
  [zss,lonss,latss]=mygrid_sand( ...
	[minlon maxlon minlat maxlat]);
  latss=latss'*ones(1,size(zss,2)); 
  lonss=ones(size(latss,1),1)*lonss; 
  weight=exp(-(latss-lat(i)).^2/(del(i)/2)^2 ...
	-(lonss-lon(i)).^2/(del(i)/2)^2);
  weightedz=weight.*zss;
  q=find(isfinite(zss));
  smith_sand_bottom(i,1)=-sum(zss(q).*weight(q)) ...
	./sum(weight(q));
  q2=find(zss==max(zss(q)));
  smith_sand_bottom(i,2)=-zss(q2(1));
  q2=find(zss==min(zss(q)));
  smith_sand_bottom(i,3)=-zss(q2(1));
end;
fprintf('\n');
hold off;
overlay;
axis([min(lon)-1 max(lon)+1 min(lat)-1 max(lat)+1]);

deepestobs=NaN*ones(size(lon));
for i=1:length(lon);
  deepestobs(i)=ctdpres(max(find( ...
	isfinite(ctdsal(:,i)+ctdtemp(:,i)))));
end;
subplot(212);
plot(smith_sand_bottom(:,1),'w');
hold on;
patch([(1:length(lon))';flipud((1:length(lon))')], ...
	-[smith_sand_bottom(:,2);flipud( ...
	smith_sand_bottom(:,3))], ...
	[.8 .8 .8],'edgecolor','none');
plot(-smith_sand_bottom(:,1),'color',[.25 .25 .25]);
plot(-bottom,'.k');
plot(-deepestobs,'ok','markersize',5);
hold off;
axis([0 length(lon)+1 min(min(-smith_sand_bottom)) 0]);

ind=round(1:length(lon)/10:length(lon));
set(gca,'xtick',ind,'xticklabel', ...
  num2str(round(lon(ind)')) );
title(['bottom depth (dots), ', ...
	'deepest obs (circles) and ', ...
	'Smith&Sandwell bottom (line)']);

clear minlat maxlat minlon maxlon latss lonss zss
clear weight weightedz del dlat dlon i q q2 ind
