% define the gamma values which divide the
% water column into named masses
% (within which fluxes, etc. will be averaged)

if (1)      % individual layers used by Lynne Talley: note that her layer 1
            % is Ekman, while massnum=1 gives just the lightest layer
            % of this model.  Her interfaces for layers 2-20 are:
            % sfc 26.14  26.45 27.0  27.23  27.58  27.84  28.04 28.10 28.15
            % 28.23   bottom        Add 22 as interface for layer 1, so
            % this routine's layer 9 is Lynne's layer 9.
    waterdivs=[21 26.14  26.45 27.0  27.23  27.58  27.84  28.04 28.10 28.15  28.23];
    waterdivslab=['layer 1 (\gamma^n<21)    '; ...
                  'layer 2 (21-26.14)       '; ...
              'layer 3 (26.14-26.45)    '; ...
              'layer 4 (26.45-27.0)     '; ...
              'layer 5 (27.0-27.23)     '; ...
              'layer 6 (27.23-27.58)    '; ...
              'layer 7 (27.58-27.84)    '; ...
              'layer 8 (27.84-28.04)    '; ...
              'layer 9 (28.04-28.10)    '; ...
              'layer 10 (28.10-28.15)   '; ...
              'layer 11 (28.15-28.23)   '; ...
              'layer 12 (\gamma^n>28.23)']; 
elseif (0)  % subsets of Talley's layers for S. Indian Ocean
    waterdivs=[26.45 27.0 27.84  28.04];
    waterdivslab=[' layers 1-3                   '; ... 
              'SAMW layer 4 (26.45-27.0)     '; ... 
              ' disregard intermediate layers'; ...
              'NADW layer 8 (27.84-28.04)    '; ... 
              'AABW layers 9-12              '];
elseif (0)  % subsets of Talley's layers for S. Pacific Ocean
    waterdivs=[27.0 27.23 28.04];
    waterdivslab=[' TCline layers 1-4            '; ... 
               'SAMW layer 5 (27.0-27.23)     '; ... 
              ' disregard intermediate layers '; ... 
              'AABW layers 10-12              '];    
elseif (0)  % subsets of Talley's layers for S. Atlantic Ocean 
    waterdivs=[26.45 27.58 28.1];
    waterdivslab=[' layers 1-3                   '; ... 
              'AAIW layers 4-6               '; ... 
              ' disregard intermediate       '; ...
              'AABW layers 10-12             '];        
elseif (0)  % subsets of Talley's layers for N. Atlantic Ocean 
    waterdivs=[26.45 27.58 28.1];
    waterdivslab=[' layers 1-3                   '; ... 
              'AAIW layers 4-6               '; ... 
              ' disregard intermediate       '; ...
              'AABW layers 10-12             '];                  
elseif (0)	% Atlantic division
  waterdivs=[26.0 27.2 27.88 27.976 28.13];
  waterdivslab=['       surface (\gamma^n<26.0)     '; ...
              '   t-cline (26.0<=\gamma^n<27.2)   '; ...
              '  intermed (27.2<=\gamma^n<27.88)  '; ...
              'upper deep (27.88<=\gamma^n<27.976)'; ...
              'lower deep (27.976<=\gamma^n<28.13)'; ...
              '      bottom (\gamma^n>=28.13)     '];
  swaterdivslab=['SFC';'TC ';'INT';'UD ';'LD ';'BOT'];
elseif (0)	% Indian Ocean (Agulhas)
  waterdivs=[25.5 26.4 27.0 27.92 28.08];
  waterdivslab=['       TSW (\gamma^n<25.5)         '; ...
                '   STSW (25.5<=\gamma^n<26.4)      '; ...
                '  SICW (26.4<=\gamma^n<27.0)       '; ...
                '  AAIW & RSW (27.0<=\gamma^n<27.92)'; ...
                ' Upper NADW (27.92<=\gamma^n<28.08)'; ...
                ' Lower NADW (\gamma^n>=28.08)      '];
  swaterdivslab=['TSW  ';'STSW ';'SICW ';'AAIW ';'UNADW';'LNADW'];
elseif (0)	% NADW division into U,M,L
  waterdivs=[27.879 27.998 28.063 28.127];
  waterdivslab=['   ';'UDW';'MDW';'LDW';'BOT'];
  swaterdivslab=waterdivslab;
elseif (0)	% Sauders and King (1995) divisions
  waterdivs=[26.885 27.83 28.175];
elseif (0)  % Sloyan and Rintoul (2001) divisions
  waterdivs=[26.0 27.4 28.0 28.2];
  waterdivslab=['   TW (\gamma^n<26.0)   '; ...
                ' IW (26.0<\gamma^n<27.4)'; ...
		        'UDW (27.4<\gamma^n<28.0)'; ...
		        'LDW (28.0<\gamma^n<28.2)'; ...
		        '   BW (\gamma^n>28.2)   '];
  swaterdivslab=['TW ';'IW ';'UDW';'LDW';'BW '];
elseif (0)  % MICOM layers (approx)
    glev_micom
    waterdivs=glevels_micom;
    waterdivslab=num2str(layers_micom);
    swaterdivslab=waterdivslab;
elseif (0)  % LSW and LDW (48N paper)
    waterdivs=[27.88 27.98 28.06 28.12];
    waterdivslab=['TW ';'LSW';'DW ';'LDW';'BW '];
    swaterdivslab=waterdivslab;
elseif (0)		% Alex Orsi's divisions for SO water
		% (added 26.99 to put upper cap on UCDW;
		%  this divides low O2 UCDW fr/ high O2)
		% (removed for now 28.05.  Lies within LCDW)
        %  changed 18 Nov 2003: 28.15 instead of 28.2
        %  as LCDW/ACCbw interface density
  waterdivs=[26.0 27.0 27.84 28.15 28.27];
  waterdivslab=['     TW (\gamma^n<26.0)     '; ...
                '  MW (26.0<\gamma^n<27.0)   '; ...
		        'UCDW (27.0<\gamma^n<27.84)  '; ...
		        'LCDW (27.84<\gamma^n<28.15) '; ...
		        'ACCbw (28.15<\gamma^n<28.27)'; ...
		        '   AABW (\gamma^n>28.27)    '];
  swaterdivslab=['TW  ';'MW  ';'UCDW';'LCDW';'ACCb';'AABW'];
else        % Alex Orsi's "top", "middle" and "bottom" layers
    waterdivs=[27.7 27.98 28.27];
    waterdivslab=[  '    upper (\gamma^n<27.7)    '; ...
                    '  Top (27.7<\gamma^n<27.98)  '; ...
                    'Middle (27.98<\gamma^n<28.27)'; ...
                    '  Bottom (\gamma^n>28.27)    '];
end;

